@@ -17,6 +17,7 @@ from typing import (
     TYPE_CHECKING,
 )
 from litellm.types.integrations.datadog_llm_obs import DatadogLLMObsInitParams
+from litellm.types.integrations.datadog import DatadogInitParams
 from litellm.llms.custom_httpx.http_handler import AsyncHTTPHandler, HTTPHandler
 from litellm.caching.caching import Cache, DualCache, RedisCache, InMemoryCache
 from litellm.caching.llm_caching_handler import LLMClientCache
@@ -60,6 +61,7 @@ from litellm.constants import (
     empower_models,
     together_ai_models,
     baseten_models,
+    WANDB_MODELS,
     REPEATED_STREAMING_CHUNK_LIMIT,
     request_timeout,
     open_ai_embedding_models,
@@ -67,6 +69,8 @@ from litellm.constants import (
     bedrock_embedding_models,
     known_tokenizer_config,
     BEDROCK_INVOKE_PROVIDERS_LITERAL,
+    BEDROCK_EMBEDDING_PROVIDERS_LITERAL,
+    BEDROCK_CONVERSE_MODELS,
     DEFAULT_MAX_TOKENS,
     DEFAULT_SOFT_BUDGET,
     DEFAULT_ALLOWED_FAILS,
@@ -86,6 +90,7 @@ from litellm.types.proxy.management_endpoints.ui_sso import (
     LiteLLM_UpperboundKeyGenerateParams,
 )
 from litellm.types.utils import StandardKeyGenerationConfig, LlmProviders
+from litellm.types.utils import PriorityReservationSettings
 from litellm.integrations.custom_logger import CustomLogger
 from litellm.litellm_core_utils.logging_callback_manager import LoggingCallbackManager
 import httpx
@@ -115,6 +120,7 @@ _custom_logger_compatible_callbacks_literal = Literal[
     "logfire",
     "literalai",
     "dynamic_rate_limiter",
+    "dynamic_rate_limiter_v3",
     "langsmith",
     "prometheus",
     "otel",
@@ -145,7 +151,13 @@ _custom_logger_compatible_callbacks_literal = Literal[
     "aws_sqs",
     "vector_store_pre_call_hook",
     "dotprompt",
+    "bitbucket",
+    "cloudzero",
+    "posthog",
 ]
+configured_cold_storage_logger: Optional[
+    _custom_logger_compatible_callbacks_literal
+] = None
 logged_real_time_event_types: Optional[Union[List[str], Literal["*"]]] = None
 _known_custom_logger_compatible_callbacks: List = list(
     get_args(_custom_logger_compatible_callbacks_literal)
@@ -225,6 +237,7 @@ vertex_location: Optional[str] = None
 predibase_tenant_id: Optional[str] = None
 togetherai_api_key: Optional[str] = None
 cloudflare_api_key: Optional[str] = None
+vercel_ai_gateway_key: Optional[str] = None
 baseten_key: Optional[str] = None
 llama_api_key: Optional[str] = None
 aleph_alpha_key: Optional[str] = None
@@ -233,7 +246,10 @@ novita_api_key: Optional[str] = None
 snowflake_key: Optional[str] = None
 gradient_ai_api_key: Optional[str] = None
 nebius_key: Optional[str] = None
+wandb_key: Optional[str] = None
+heroku_key: Optional[str] = None
 cometapi_key: Optional[str] = None
+ovhcloud_key: Optional[str] = None
 common_cloud_provider_auth_params: dict = {
     "params": ["project", "region_name", "token"],
     "providers": ["vertex_ai", "bedrock", "watsonx", "azure", "vertex_ai_beta"],
@@ -303,7 +319,6 @@ default_in_memory_ttl: Optional[float] = None
 default_redis_ttl: Optional[float] = None
 default_redis_batch_cache_expiry: Optional[float] = None
 model_alias_map: Dict[str, str] = {}
-model_group_alias_map: Dict[str, str] = {}
 model_group_settings: Optional["ModelGroupSettings"] = None
 max_budget: float = 0.0  # set the max budget across all providers
 budget_duration: Optional[str] = (
@@ -330,6 +345,7 @@ suppress_debug_info = False
 dynamodb_table_name: Optional[str] = None
 s3_callback_params: Optional[Dict] = None
 datadog_llm_observability_params: Optional[Union[DatadogLLMObsInitParams, Dict]] = None
+datadog_params: Optional[Union[DatadogInitParams, Dict]] = None
 aws_sqs_callback_params: Optional[Dict] = None
 generic_logger_headers: Optional[Dict] = None
 default_key_generate_params: Optional[Dict] = None
@@ -361,6 +377,9 @@ public_model_groups: Optional[List[str]] = None
 public_model_groups_links: Dict[str, str] = {}
 #### REQUEST PRIORITIZATION ######
 priority_reservation: Optional[Dict[str, float]] = None
+priority_reservation_settings: "PriorityReservationSettings" = (
+    PriorityReservationSettings()
+)
 
 
 ######## Networking Settings ########
@@ -426,120 +445,97 @@ def identify(event_details):
 ####### ADDITIONAL PARAMS ################### configurable params if you use proxy models like Helicone, map spend to org id, etc.
 api_base: Optional[str] = None
 headers = None
-api_version = None
+api_version: Optional[str] = None
 organization = None
 project = None
 config_path = None
 vertex_ai_safety_settings: Optional[dict] = None
-BEDROCK_CONVERSE_MODELS = [
-    "openai.gpt-oss-20b-1:0",
-    "openai.gpt-oss-120b-1:0",
-    "anthropic.claude-opus-4-1-20250805-v1:0",
-    "anthropic.claude-opus-4-20250514-v1:0",
-    "anthropic.claude-sonnet-4-20250514-v1:0",
-    "anthropic.claude-3-7-sonnet-20250219-v1:0",
-    "anthropic.claude-3-5-haiku-20241022-v1:0",
-    "anthropic.claude-3-5-sonnet-20241022-v2:0",
-    "anthropic.claude-3-5-sonnet-20240620-v1:0",
-    "anthropic.claude-3-opus-20240229-v1:0",
-    "anthropic.claude-3-sonnet-20240229-v1:0",
-    "anthropic.claude-3-haiku-20240307-v1:0",
-    "anthropic.claude-v2",
-    "anthropic.claude-v2:1",
-    "anthropic.claude-v1",
-    "anthropic.claude-instant-v1",
-    "ai21.jamba-instruct-v1:0",
-    "ai21.jamba-1-5-mini-v1:0",
-    "ai21.jamba-1-5-large-v1:0",
-    "meta.llama3-70b-instruct-v1:0",
-    "meta.llama3-8b-instruct-v1:0",
-    "meta.llama3-1-8b-instruct-v1:0",
-    "meta.llama3-1-70b-instruct-v1:0",
-    "meta.llama3-1-405b-instruct-v1:0",
-    "meta.llama3-70b-instruct-v1:0",
-    "mistral.mistral-large-2407-v1:0",
-    "mistral.mistral-large-2402-v1:0",
-    "mistral.mistral-small-2402-v1:0",
-    "meta.llama3-2-1b-instruct-v1:0",
-    "meta.llama3-2-3b-instruct-v1:0",
-    "meta.llama3-2-11b-instruct-v1:0",
-    "meta.llama3-2-90b-instruct-v1:0",
-]
 
 ####### COMPLETION MODELS ###################
-open_ai_chat_completion_models: List = []
-open_ai_text_completion_models: List = []
-cohere_models: List = []
-cohere_chat_models: List = []
-mistral_chat_models: List = []
-text_completion_codestral_models: List = []
-anthropic_models: List = []
-openrouter_models: List = []
-datarobot_models: List = []
-vertex_language_models: List = []
-vertex_vision_models: List = []
-vertex_chat_models: List = []
-vertex_code_chat_models: List = []
-vertex_ai_image_models: List = []
-vertex_text_models: List = []
-vertex_code_text_models: List = []
-vertex_embedding_models: List = []
-vertex_anthropic_models: List = []
-vertex_llama3_models: List = []
-vertex_deepseek_models: List = []
-vertex_ai_ai21_models: List = []
-vertex_mistral_models: List = []
-ai21_models: List = []
-ai21_chat_models: List = []
-nlp_cloud_models: List = []
-aleph_alpha_models: List = []
-bedrock_models: List = []
-bedrock_converse_models: List = BEDROCK_CONVERSE_MODELS
-fireworks_ai_models: List = []
-fireworks_ai_embedding_models: List = []
-deepinfra_models: List = []
-perplexity_models: List = []
-watsonx_models: List = []
-gemini_models: List = []
-xai_models: List = []
-deepseek_models: List = []
-azure_ai_models: List = []
-jina_ai_models: List = []
-voyage_models: List = []
-infinity_models: List = []
-databricks_models: List = []
-cloudflare_models: List = []
-codestral_models: List = []
-friendliai_models: List = []
-featherless_ai_models: List = []
-palm_models: List = []
-groq_models: List = []
-azure_models: List = []
-azure_text_models: List = []
-anyscale_models: List = []
-cerebras_models: List = []
-galadriel_models: List = []
-sambanova_models: List = []
-sambanova_embedding_models: List = []
-novita_models: List = []
-assemblyai_models: List = []
-snowflake_models: List = []
-gradient_ai_models: List = []
-llama_models: List = []
-nscale_models: List = []
-nebius_models: List = []
-nebius_embedding_models: List = []
-deepgram_models: List = []
-elevenlabs_models: List = []
-dashscope_models: List = []
-moonshot_models: List = []
-v0_models: List = []
-morph_models: List = []
-lambda_ai_models: List = []
-hyperbolic_models: List = []
-recraft_models: List = []
-cometapi_models: List = []
-oci_models: List = []
+from typing import Set
+
+open_ai_chat_completion_models: Set = set()
+open_ai_text_completion_models: Set = set()
+cohere_models: Set = set()
+cohere_chat_models: Set = set()
+mistral_chat_models: Set = set()
+text_completion_codestral_models: Set = set()
+anthropic_models: Set = set()
+openrouter_models: Set = set()
+datarobot_models: Set = set()
+vertex_language_models: Set = set()
+vertex_vision_models: Set = set()
+vertex_chat_models: Set = set()
+vertex_code_chat_models: Set = set()
+vertex_ai_image_models: Set = set()
+vertex_ai_video_models: Set = set()
+vertex_text_models: Set = set()
+vertex_code_text_models: Set = set()
+vertex_embedding_models: Set = set()
+vertex_anthropic_models: Set = set()
+vertex_llama3_models: Set = set()
+vertex_deepseek_models: Set = set()
+vertex_ai_ai21_models: Set = set()
+vertex_mistral_models: Set = set()
+vertex_openai_models: Set = set()
+ai21_models: Set = set()
+ai21_chat_models: Set = set()
+nlp_cloud_models: Set = set()
+aleph_alpha_models: Set = set()
+bedrock_models: Set = set()
+bedrock_converse_models: Set = set(BEDROCK_CONVERSE_MODELS)
+fireworks_ai_models: Set = set()
+fireworks_ai_embedding_models: Set = set()
+deepinfra_models: Set = set()
+perplexity_models: Set = set()
+watsonx_models: Set = set()
+gemini_models: Set = set()
+xai_models: Set = set()
+deepseek_models: Set = set()
+azure_ai_models: Set = set()
+jina_ai_models: Set = set()
+voyage_models: Set = set()
+infinity_models: Set = set()
+heroku_models: Set = set()
+databricks_models: Set = set()
+cloudflare_models: Set = set()
+codestral_models: Set = set()
+friendliai_models: Set = set()
+featherless_ai_models: Set = set()
+palm_models: Set = set()
+groq_models: Set = set()
+azure_models: Set = set()
+azure_text_models: Set = set()
+anyscale_models: Set = set()
+cerebras_models: Set = set()
+galadriel_models: Set = set()
+sambanova_models: Set = set()
+sambanova_embedding_models: Set = set()
+novita_models: Set = set()
+assemblyai_models: Set = set()
+snowflake_models: Set = set()
+gradient_ai_models: Set = set()
+llama_models: Set = set()
+nscale_models: Set = set()
+nebius_models: Set = set()
+nebius_embedding_models: Set = set()
+aiml_models: Set = set()
+deepgram_models: Set = set()
+elevenlabs_models: Set = set()
+dashscope_models: Set = set()
+moonshot_models: Set = set()
+v0_models: Set = set()
+morph_models: Set = set()
+lambda_ai_models: Set = set()
+hyperbolic_models: Set = set()
+recraft_models: Set = set()
+cometapi_models: Set = set()
+oci_models: Set = set()
+vercel_ai_gateway_models: Set = set()
+volcengine_models: Set = set()
+wandb_models: Set = set(WANDB_MODELS)
+ovhcloud_models: Set = set()
+ovhcloud_embedding_models: Set = set()
 
 
 def is_bedrock_pricing_only_model(key: str) -> bool:
@@ -580,166 +576,186 @@ def add_known_models():
         if value.get("litellm_provider") == "openai" and not is_openai_finetune_model(
             key
         ):
-            open_ai_chat_completion_models.append(key)
+            open_ai_chat_completion_models.add(key)
         elif value.get("litellm_provider") == "text-completion-openai":
-            open_ai_text_completion_models.append(key)
+            open_ai_text_completion_models.add(key)
         elif value.get("litellm_provider") == "azure_text":
-            azure_text_models.append(key)
+            azure_text_models.add(key)
         elif value.get("litellm_provider") == "cohere":
-            cohere_models.append(key)
+            cohere_models.add(key)
         elif value.get("litellm_provider") == "cohere_chat":
-            cohere_chat_models.append(key)
+            cohere_chat_models.add(key)
         elif value.get("litellm_provider") == "mistral":
-            mistral_chat_models.append(key)
+            mistral_chat_models.add(key)
         elif value.get("litellm_provider") == "anthropic":
-            anthropic_models.append(key)
+            anthropic_models.add(key)
         elif value.get("litellm_provider") == "empower":
-            empower_models.append(key)
+            empower_models.add(key)
         elif value.get("litellm_provider") == "openrouter":
-            openrouter_models.append(key)
+            openrouter_models.add(key)
+        elif value.get("litellm_provider") == "vercel_ai_gateway":
+            vercel_ai_gateway_models.add(key)
         elif value.get("litellm_provider") == "datarobot":
-            datarobot_models.append(key)
+            datarobot_models.add(key)
         elif value.get("litellm_provider") == "vertex_ai-text-models":
-            vertex_text_models.append(key)
+            vertex_text_models.add(key)
         elif value.get("litellm_provider") == "vertex_ai-code-text-models":
-            vertex_code_text_models.append(key)
+            vertex_code_text_models.add(key)
         elif value.get("litellm_provider") == "vertex_ai-language-models":
-            vertex_language_models.append(key)
+            vertex_language_models.add(key)
         elif value.get("litellm_provider") == "vertex_ai-vision-models":
-            vertex_vision_models.append(key)
+            vertex_vision_models.add(key)
         elif value.get("litellm_provider") == "vertex_ai-chat-models":
-            vertex_chat_models.append(key)
+            vertex_chat_models.add(key)
         elif value.get("litellm_provider") == "vertex_ai-code-chat-models":
-            vertex_code_chat_models.append(key)
+            vertex_code_chat_models.add(key)
         elif value.get("litellm_provider") == "vertex_ai-embedding-models":
-            vertex_embedding_models.append(key)
+            vertex_embedding_models.add(key)
         elif value.get("litellm_provider") == "vertex_ai-anthropic_models":
             key = key.replace("vertex_ai/", "")
-            vertex_anthropic_models.append(key)
+            vertex_anthropic_models.add(key)
         elif value.get("litellm_provider") == "vertex_ai-llama_models":
             key = key.replace("vertex_ai/", "")
-            vertex_llama3_models.append(key)
+            vertex_llama3_models.add(key)
         elif value.get("litellm_provider") == "vertex_ai-deepseek_models":
             key = key.replace("vertex_ai/", "")
-            vertex_deepseek_models.append(key)
+            vertex_deepseek_models.add(key)
         elif value.get("litellm_provider") == "vertex_ai-mistral_models":
             key = key.replace("vertex_ai/", "")
-            vertex_mistral_models.append(key)
+            vertex_mistral_models.add(key)
         elif value.get("litellm_provider") == "vertex_ai-ai21_models":
             key = key.replace("vertex_ai/", "")
-            vertex_ai_ai21_models.append(key)
+            vertex_ai_ai21_models.add(key)
         elif value.get("litellm_provider") == "vertex_ai-image-models":
             key = key.replace("vertex_ai/", "")
-            vertex_ai_image_models.append(key)
+            vertex_ai_image_models.add(key)
+        elif value.get("litellm_provider") == "vertex_ai-video-models":
+            key = key.replace("vertex_ai/", "")
+            vertex_ai_video_models.add(key)
+        elif value.get("litellm_provider") == "vertex_ai-openai_models":
+            key = key.replace("vertex_ai/", "")
+            vertex_openai_models.add(key)
         elif value.get("litellm_provider") == "ai21":
             if value.get("mode") == "chat":
-                ai21_chat_models.append(key)
+                ai21_chat_models.add(key)
             else:
-                ai21_models.append(key)
+                ai21_models.add(key)
         elif value.get("litellm_provider") == "nlp_cloud":
-            nlp_cloud_models.append(key)
+            nlp_cloud_models.add(key)
         elif value.get("litellm_provider") == "aleph_alpha":
-            aleph_alpha_models.append(key)
+            aleph_alpha_models.add(key)
         elif value.get(
             "litellm_provider"
         ) == "bedrock" and not is_bedrock_pricing_only_model(key):
-            bedrock_models.append(key)
+            bedrock_models.add(key)
         elif value.get("litellm_provider") == "bedrock_converse":
-            bedrock_converse_models.append(key)
+            bedrock_converse_models.add(key)
         elif value.get("litellm_provider") == "deepinfra":
-            deepinfra_models.append(key)
+            deepinfra_models.add(key)
         elif value.get("litellm_provider") == "perplexity":
-            perplexity_models.append(key)
+            perplexity_models.add(key)
         elif value.get("litellm_provider") == "watsonx":
-            watsonx_models.append(key)
+            watsonx_models.add(key)
         elif value.get("litellm_provider") == "gemini":
-            gemini_models.append(key)
+            gemini_models.add(key)
         elif value.get("litellm_provider") == "fireworks_ai":
             # ignore the 'up-to', '-to-' model names -> not real models. just for cost tracking based on model params.
             if "-to-" not in key and "fireworks-ai-default" not in key:
-                fireworks_ai_models.append(key)
+                fireworks_ai_models.add(key)
         elif value.get("litellm_provider") == "fireworks_ai-embedding-models":
             # ignore the 'up-to', '-to-' model names -> not real models. just for cost tracking based on model params.
             if "-to-" not in key:
-                fireworks_ai_embedding_models.append(key)
+                fireworks_ai_embedding_models.add(key)
         elif value.get("litellm_provider") == "text-completion-codestral":
-            text_completion_codestral_models.append(key)
+            text_completion_codestral_models.add(key)
         elif value.get("litellm_provider") == "xai":
-            xai_models.append(key)
+            xai_models.add(key)
         elif value.get("litellm_provider") == "deepseek":
-            deepseek_models.append(key)
+            deepseek_models.add(key)
         elif value.get("litellm_provider") == "meta_llama":
-            llama_models.append(key)
+            llama_models.add(key)
         elif value.get("litellm_provider") == "nscale":
-            nscale_models.append(key)
+            nscale_models.add(key)
         elif value.get("litellm_provider") == "azure_ai":
-            azure_ai_models.append(key)
+            azure_ai_models.add(key)
         elif value.get("litellm_provider") == "voyage":
-            voyage_models.append(key)
+            voyage_models.add(key)
         elif value.get("litellm_provider") == "infinity":
-            infinity_models.append(key)
+            infinity_models.add(key)
         elif value.get("litellm_provider") == "databricks":
-            databricks_models.append(key)
+            databricks_models.add(key)
         elif value.get("litellm_provider") == "cloudflare":
-            cloudflare_models.append(key)
+            cloudflare_models.add(key)
         elif value.get("litellm_provider") == "codestral":
-            codestral_models.append(key)
+            codestral_models.add(key)
         elif value.get("litellm_provider") == "friendliai":
-            friendliai_models.append(key)
+            friendliai_models.add(key)
         elif value.get("litellm_provider") == "palm":
-            palm_models.append(key)
+            palm_models.add(key)
         elif value.get("litellm_provider") == "groq":
-            groq_models.append(key)
+            groq_models.add(key)
         elif value.get("litellm_provider") == "azure":
-            azure_models.append(key)
+            azure_models.add(key)
         elif value.get("litellm_provider") == "anyscale":
-            anyscale_models.append(key)
+            anyscale_models.add(key)
         elif value.get("litellm_provider") == "cerebras":
-            cerebras_models.append(key)
+            cerebras_models.add(key)
         elif value.get("litellm_provider") == "galadriel":
-            galadriel_models.append(key)
+            galadriel_models.add(key)
         elif value.get("litellm_provider") == "sambanova":
-            sambanova_models.append(key)
+            sambanova_models.add(key)
         elif value.get("litellm_provider") == "sambanova-embedding-models":
-            sambanova_embedding_models.append(key)
+            sambanova_embedding_models.add(key)
         elif value.get("litellm_provider") == "novita":
-            novita_models.append(key)
+            novita_models.add(key)
         elif value.get("litellm_provider") == "nebius-chat-models":
-            nebius_models.append(key)
+            nebius_models.add(key)
         elif value.get("litellm_provider") == "nebius-embedding-models":
-            nebius_embedding_models.append(key)
+            nebius_embedding_models.add(key)
+        elif value.get("litellm_provider") == "aiml":
+            aiml_models.add(key)
         elif value.get("litellm_provider") == "assemblyai":
-            assemblyai_models.append(key)
+            assemblyai_models.add(key)
         elif value.get("litellm_provider") == "jina_ai":
-            jina_ai_models.append(key)
+            jina_ai_models.add(key)
         elif value.get("litellm_provider") == "snowflake":
-            snowflake_models.append(key)
+            snowflake_models.add(key)
         elif value.get("litellm_provider") == "gradient_ai":
-            gradient_ai_models.append(key)
+            gradient_ai_models.add(key)
         elif value.get("litellm_provider") == "featherless_ai":
-            featherless_ai_models.append(key)
+            featherless_ai_models.add(key)
         elif value.get("litellm_provider") == "deepgram":
-            deepgram_models.append(key)
+            deepgram_models.add(key)
         elif value.get("litellm_provider") == "elevenlabs":
-            elevenlabs_models.append(key)
+            elevenlabs_models.add(key)
+        elif value.get("litellm_provider") == "heroku":
+            heroku_models.add(key)
         elif value.get("litellm_provider") == "dashscope":
-            dashscope_models.append(key)
+            dashscope_models.add(key)
         elif value.get("litellm_provider") == "moonshot":
-            moonshot_models.append(key)
+            moonshot_models.add(key)
         elif value.get("litellm_provider") == "v0":
-            v0_models.append(key)
+            v0_models.add(key)
         elif value.get("litellm_provider") == "morph":
-            morph_models.append(key)
+            morph_models.add(key)
         elif value.get("litellm_provider") == "lambda_ai":
-            lambda_ai_models.append(key)
+            lambda_ai_models.add(key)
         elif value.get("litellm_provider") == "hyperbolic":
-            hyperbolic_models.append(key)
+            hyperbolic_models.add(key)
         elif value.get("litellm_provider") == "recraft":
-            recraft_models.append(key)
+            recraft_models.add(key)
         elif value.get("litellm_provider") == "cometapi":
-            cometapi_models.append(key)
+            cometapi_models.add(key)
         elif value.get("litellm_provider") == "oci":
-            oci_models.append(key)
+            oci_models.add(key)
+        elif value.get("litellm_provider") == "volcengine":
+            volcengine_models.add(key)
+        elif value.get("litellm_provider") == "wandb":
+            wandb_models.add(key)
+        elif value.get("litellm_provider") == "ovhcloud":
+            ovhcloud_models.add(key)
+        elif value.get("litellm_provider") == "ovhcloud-embedding-models":
+            ovhcloud_embedding_models.add(key)
 
 
 add_known_models()
@@ -769,68 +785,73 @@ ollama_models = ["llama2"]
 
 maritalk_models = ["maritalk"]
 
-model_list = (
+model_list = list(
     open_ai_chat_completion_models
-    + open_ai_text_completion_models
-    + cohere_models
-    + cohere_chat_models
-    + anthropic_models
-    + replicate_models
-    + openrouter_models
-    + datarobot_models
-    + huggingface_models
-    + vertex_chat_models
-    + vertex_text_models
-    + ai21_models
-    + ai21_chat_models
-    + together_ai_models
-    + baseten_models
-    + aleph_alpha_models
-    + nlp_cloud_models
-    + ollama_models
-    + bedrock_models
-    + deepinfra_models
-    + perplexity_models
-    + maritalk_models
-    + vertex_language_models
-    + watsonx_models
-    + gemini_models
-    + text_completion_codestral_models
-    + xai_models
-    + deepseek_models
-    + azure_ai_models
-    + voyage_models
-    + infinity_models
-    + databricks_models
-    + cloudflare_models
-    + codestral_models
-    + friendliai_models
-    + palm_models
-    + groq_models
-    + azure_models
-    + anyscale_models
-    + cerebras_models
-    + galadriel_models
-    + sambanova_models
-    + azure_text_models
-    + novita_models
-    + assemblyai_models
-    + jina_ai_models
-    + snowflake_models
-    + gradient_ai_models
-    + llama_models
-    + featherless_ai_models
-    + nscale_models
-    + deepgram_models
-    + elevenlabs_models
-    + dashscope_models
-    + moonshot_models
-    + v0_models
-    + morph_models
-    + lambda_ai_models
-    + recraft_models
-    + cometapi_models
-    + oci_models
+    | open_ai_text_completion_models
+    | cohere_models
+    | cohere_chat_models
+    | anthropic_models
+    | set(replicate_models)
+    | openrouter_models
+    | datarobot_models
+    | set(huggingface_models)
+    | vertex_chat_models
+    | vertex_text_models
+    | ai21_models
+    | ai21_chat_models
+    | set(together_ai_models)
+    | set(baseten_models)
+    | aleph_alpha_models
+    | nlp_cloud_models
+    | set(ollama_models)
+    | bedrock_models
+    | deepinfra_models
+    | perplexity_models
+    | set(maritalk_models)
+    | vertex_language_models
+    | watsonx_models
+    | gemini_models
+    | text_completion_codestral_models
+    | xai_models
+    | deepseek_models
+    | azure_ai_models
+    | voyage_models
+    | infinity_models
+    | databricks_models
+    | cloudflare_models
+    | codestral_models
+    | friendliai_models
+    | palm_models
+    | groq_models
+    | azure_models
+    | anyscale_models
+    | cerebras_models
+    | galadriel_models
+    | sambanova_models
+    | azure_text_models
+    | novita_models
+    | assemblyai_models
+    | jina_ai_models
+    | snowflake_models
+    | gradient_ai_models
+    | llama_models
+    | featherless_ai_models
+    | nscale_models
+    | deepgram_models
+    | elevenlabs_models
+    | dashscope_models
+    | moonshot_models
+    | v0_models
+    | morph_models
+    | lambda_ai_models
+    | recraft_models
+    | cometapi_models
+    | oci_models
+    | heroku_models
+    | vercel_ai_gateway_models
+    | volcengine_models
+    | wandb_models
+    | ovhcloud_models
 )
 
 model_list_set = set(model_list)
@@ -839,9 +860,9 @@ provider_list: List[Union[LlmProviders, str]] = list(LlmProviders)
 
 
 models_by_provider: dict = {
-    "openai": open_ai_chat_completion_models + open_ai_text_completion_models,
+    "openai": open_ai_chat_completion_models | open_ai_text_completion_models,
     "text-completion-openai": open_ai_text_completion_models,
-    "cohere": cohere_models + cohere_chat_models,
+    "cohere": cohere_models | cohere_chat_models,
     "cohere_chat": cohere_chat_models,
     "anthropic": anthropic_models,
     "replicate": replicate_models,
@@ -849,15 +870,16 @@ models_by_provider: dict = {
     "together_ai": together_ai_models,
     "baseten": baseten_models,
     "openrouter": openrouter_models,
+    "vercel_ai_gateway": vercel_ai_gateway_models,
     "datarobot": datarobot_models,
     "vertex_ai": vertex_chat_models
-    + vertex_text_models
-    + vertex_anthropic_models
-    + vertex_vision_models
-    + vertex_language_models
-    + vertex_deepseek_models,
+    | vertex_text_models
+    | vertex_anthropic_models
+    | vertex_vision_models
+    | vertex_language_models
+    | vertex_deepseek_models,
     "ai21": ai21_models,
-    "bedrock": bedrock_models + bedrock_converse_models,
+    "bedrock": bedrock_models | bedrock_converse_models,
     "petals": petals_models,
     "ollama": ollama_models,
     "ollama_chat": ollama_models,
@@ -866,7 +888,7 @@ models_by_provider: dict = {
     "maritalk": maritalk_models,
     "watsonx": watsonx_models,
     "gemini": gemini_models,
-    "fireworks_ai": fireworks_ai_models + fireworks_ai_embedding_models,
+    "fireworks_ai": fireworks_ai_models | fireworks_ai_embedding_models,
     "aleph_alpha": aleph_alpha_models,
     "text-completion-codestral": text_completion_codestral_models,
     "xai": xai_models,
@@ -882,14 +904,15 @@ models_by_provider: dict = {
     "friendliai": friendliai_models,
     "palm": palm_models,
     "groq": groq_models,
-    "azure": azure_models + azure_text_models,
+    "azure": azure_models | azure_text_models,
     "azure_text": azure_text_models,
     "anyscale": anyscale_models,
     "cerebras": cerebras_models,
     "galadriel": galadriel_models,
-    "sambanova": sambanova_models + sambanova_embedding_models,
+    "sambanova": sambanova_models | sambanova_embedding_models,
     "novita": novita_models,
-    "nebius": nebius_models + nebius_embedding_models,
+    "nebius": nebius_models | nebius_embedding_models,
+    "aiml": aiml_models,
     "assemblyai": assemblyai_models,
     "jina_ai": jina_ai_models,
     "snowflake": snowflake_models,
@@ -899,6 +922,7 @@ models_by_provider: dict = {
     "featherless_ai": featherless_ai_models,
     "deepgram": deepgram_models,
     "elevenlabs": elevenlabs_models,
+    "heroku": heroku_models,
     "dashscope": dashscope_models,
     "moonshot": moonshot_models,
     "v0": v0_models,
@@ -908,6 +932,9 @@ models_by_provider: dict = {
     "recraft": recraft_models,
     "cometapi": cometapi_models,
     "oci": oci_models,
+    "volcengine": volcengine_models,
+    "wandb": wandb_models,
+    "ovhcloud": ovhcloud_models | ovhcloud_embedding_models,
 }
 
 # mapping for those models which have larger equivalents
@@ -936,12 +963,13 @@ longer_context_model_fallback_dict: dict = {
 
 all_embedding_models = (
     open_ai_embedding_models
-    + cohere_embedding_models
-    + bedrock_embedding_models
-    + vertex_embedding_models
-    + fireworks_ai_embedding_models
-    + nebius_embedding_models
-    + sambanova_embedding_models
+    | set(cohere_embedding_models)
+    | set(bedrock_embedding_models)
+    | vertex_embedding_models
+    | fireworks_ai_embedding_models
+    | nebius_embedding_models
+    | sambanova_embedding_models
+    | ovhcloud_embedding_models
 )
 
 ####### IMAGE GENERATION MODELS ###################
@@ -1012,6 +1040,7 @@ from .llms.openai_like.chat.handler import OpenAILikeChatConfig
 from .llms.aiohttp_openai.chat.transformation import AiohttpOpenAIChatConfig
 from .llms.galadriel.chat.transformation import GaladrielChatConfig
 from .llms.github.chat.transformation import GithubChatConfig
+from .llms.compactifai.chat.transformation import CompactifAIChatConfig
 from .llms.empower.chat.transformation import EmpowerChatConfig
 from .llms.huggingface.chat.transformation import HuggingFaceChatConfig
 from .llms.huggingface.embedding.transformation import HuggingFaceEmbeddingConfig
@@ -1032,13 +1061,13 @@ from .llms.databricks.chat.transformation import DatabricksConfig
 from .llms.databricks.embed.transformation import DatabricksEmbeddingConfig
 from .llms.predibase.chat.transformation import PredibaseConfig
 from .llms.replicate.chat.transformation import ReplicateConfig
-from .llms.cohere.completion.transformation import CohereTextConfig as CohereConfig
 from .llms.snowflake.chat.transformation import SnowflakeConfig
 from .llms.cohere.rerank.transformation import CohereRerankConfig
 from .llms.cohere.rerank_v2.transformation import CohereRerankV2Config
 from .llms.azure_ai.rerank.transformation import AzureAIRerankConfig
 from .llms.infinity.rerank.transformation import InfinityRerankConfig
 from .llms.jina_ai.rerank.transformation import JinaAIRerankConfig
+from .llms.deepinfra.rerank.transformation import DeepinfraRerankConfig
 from .llms.clarifai.chat.transformation import ClarifaiConfig
 from .llms.ai21.chat.transformation import AI21ChatConfig, AI21ChatConfig as AI21Config
 from .llms.meta_llama.chat.transformation import LlamaAPIConfig
@@ -1150,12 +1179,17 @@ from .llms.topaz.image_variations.transformation import TopazImageVariationConfi
 from litellm.llms.openai.completion.transformation import OpenAITextCompletionConfig
 from .llms.groq.chat.transformation import GroqChatConfig
 from .llms.voyage.embedding.transformation import VoyageEmbeddingConfig
+from .llms.voyage.embedding.transformation_contextual import (
+    VoyageContextualEmbeddingConfig,
+)
 from .llms.infinity.embedding.transformation import InfinityEmbeddingConfig
 from .llms.azure_ai.chat.transformation import AzureAIStudioConfig
 from .llms.mistral.chat.transformation import MistralConfig
 from .llms.openai.responses.transformation import OpenAIResponsesAPIConfig
 from .llms.azure.responses.transformation import AzureOpenAIResponsesAPIConfig
-from .llms.azure.responses.o_series_transformation import AzureOpenAIOSeriesResponsesAPIConfig
+from .llms.azure.responses.o_series_transformation import (
+    AzureOpenAIOSeriesResponsesAPIConfig,
+)
 from .llms.openai.chat.o_series_transformation import (
     OpenAIOSeriesConfig as OpenAIO1Config,  # maintain backwards compatibility
     OpenAIOSeriesConfig,
@@ -1163,6 +1197,7 @@ from .llms.openai.chat.o_series_transformation import (
 
 from .llms.snowflake.chat.transformation import SnowflakeConfig
 from .llms.gradient_ai.chat.transformation import GradientAIConfig
+
 openaiOSeriesConfig = OpenAIOSeriesConfig()
 from .llms.openai.chat.gpt_transformation import (
     OpenAIGPTConfig,
@@ -1193,6 +1228,7 @@ nvidiaNimEmbeddingConfig = NvidiaNimEmbeddingConfig()
 
 from .llms.featherless_ai.chat.transformation import FeatherlessAIConfig
 from .llms.cerebras.chat import CerebrasConfig
+from .llms.baseten.chat import BasetenConfig
 from .llms.sambanova.chat import SambanovaConfig
 from .llms.sambanova.embedding.transformation import SambaNovaEmbeddingConfig
 from .llms.ai21.chat.transformation import AI21ChatConfig
@@ -1208,12 +1244,16 @@ from .llms.friendliai.chat.transformation import FriendliaiChatConfig
 from .llms.jina_ai.embedding.transformation import JinaAIEmbeddingConfig
 from .llms.xai.chat.transformation import XAIChatConfig
 from .llms.xai.common_utils import XAIModelInfo
-from .llms.volcengine import VolcEngineConfig
+from .llms.aiml.chat.transformation import AIMLChatConfig
+from .llms.volcengine.chat.transformation import (
+    VolcEngineChatConfig as VolcEngineConfig,
+)
 from .llms.codestral.completion.transformation import CodestralTextCompletionConfig
 from .llms.azure.azure import (
     AzureOpenAIError,
     AzureOpenAIAssistantsAPIConfig,
 )
+from .llms.heroku.chat.transformation import HerokuChatConfig
 from .llms.cometapi.chat.transformation import CometAPIConfig
 from .llms.azure.chat.gpt_transformation import AzureOpenAIConfig
 from .llms.azure.chat.gpt_5_transformation import AzureOpenAIGPT5Config
@@ -1233,6 +1273,7 @@ from .llms.watsonx.chat.transformation import IBMWatsonXChatConfig
 from .llms.watsonx.embed.transformation import IBMWatsonXEmbeddingConfig
 from .llms.github_copilot.chat.transformation import GithubCopilotConfig
 from .llms.nebius.chat.transformation import NebiusConfig
+from .llms.wandb.chat.transformation import WandbConfig
 from .llms.dashscope.chat.transformation import DashScopeChatConfig
 from .llms.moonshot.chat.transformation import MoonshotChatConfig
 from .llms.v0.chat.transformation import V0ChatConfig
@@ -1240,6 +1281,9 @@ from .llms.oci.chat.transformation import OCIChatConfig
 from .llms.morph.chat.transformation import MorphChatConfig
 from .llms.lambda_ai.chat.transformation import LambdaAIChatConfig
 from .llms.hyperbolic.chat.transformation import HyperbolicChatConfig
+from .llms.vercel_ai_gateway.chat.transformation import VercelAIGatewayConfig
+from .llms.ovhcloud.chat.transformation import OVHCloudChatConfig
+from .llms.ovhcloud.embedding.transformation import OVHCloudEmbeddingConfig
 from .main import *  # type: ignore
 from .integrations import *
 from .llms.custom_httpx.async_client_cleanup import close_litellm_async_clients
@@ -1247,6 +1291,7 @@ from .exceptions import (
     AuthenticationError,
     InvalidRequestError,
     BadRequestError,
+    ImageFetchError,
     NotFoundError,
     RateLimitError,
     ServiceUnavailableError,
@@ -1271,7 +1316,6 @@ from .router import Router
 from .assistants.main import *
 from .batches.main import *
 from .images.main import *
-from .vector_stores import *
 from .batch_completion.main import *  # type: ignore
 from .rerank_api.main import *
 from .llms.anthropic.experimental_pass_through.messages.handler import *
@@ -1306,5 +1350,17 @@ disable_hf_tokenizer_download: Optional[bool] = (
 )
 global_disable_no_log_param: bool = False
 
+### CLI UTILITIES ###
+from litellm.litellm_core_utils.cli_token_utils import get_litellm_gateway_api_key
+
 ### PASSTHROUGH ###
 from .passthrough import allm_passthrough_route, llm_passthrough_route
+
+### GLOBAL CONFIG ###
+global_bitbucket_config: Optional[Dict[str, Any]] = None
+
+
+def set_global_bitbucket_config(config: Dict[str, Any]) -> None:
+    """Set global BitBucket configuration for prompt management."""
+    global global_bitbucket_config
+    global_bitbucket_config = config
