@@ -2,5 +2,5 @@ import importlib_metadata
 
 try:
     version = importlib_metadata.version("litellm")
-except:
-    pass
+except Exception:
+    version = "unknown"
