@@ -6,6 +6,9 @@ import json
 import os
 from typing import TYPE_CHECKING, Dict, List, Literal, Optional, Union
 
+if TYPE_CHECKING:
+    from litellm.types.llms.bedrock import BedrockCreateBatchRequest
+
 import httpx
 
 import litellm
@@ -608,3 +611,223 @@ def get_anthropic_beta_from_headers(headers: dict) -> List[str]:
     
     # Split comma-separated values and strip whitespace
     return [beta.strip() for beta in anthropic_beta_header.split(",")]
+
+
+class CommonBatchFilesUtils:
+    """
+    Common utilities for Bedrock batch and file operations.
+    Provides shared functionality to reduce code duplication between batches and files.
+    """
+    
+    def __init__(self):
+        # Import here to avoid circular imports
+        from .base_aws_llm import BaseAWSLLM
+        self._base_aws = BaseAWSLLM()
+
+    def get_bedrock_model_id_from_litellm_model(self, model: str) -> str:
+        """
+        Extract the actual Bedrock model ID from LiteLLM model name.
+        
+        Args:
+            model: LiteLLM model name (e.g., "bedrock/anthropic.claude-3-sonnet-20240229-v1:0")
+            
+        Returns:
+            Bedrock model ID (e.g., "anthropic.claude-3-sonnet-20240229-v1:0")
+        """
+        if model.startswith("bedrock/"):
+            return model[8:]  # Remove "bedrock/" prefix
+        return model
+
+    def parse_s3_uri(self, s3_uri: str) -> tuple:
+        """
+        Parse S3 URI into bucket and key components.
+        
+        Args:
+            s3_uri: S3 URI (e.g., "s3://bucket/key/path")
+            
+        Returns:
+            Tuple of (bucket, key)
+            
+        Raises:
+            ValueError: If URI format is invalid
+        """
+        if not s3_uri.startswith("s3://"):
+            raise ValueError(f"Invalid S3 URI format: {s3_uri}")
+        
+        s3_parts = s3_uri[5:].split("/", 1)  # Remove "s3://" and split on first "/"
+        if len(s3_parts) != 2:
+            raise ValueError(f"Invalid S3 URI format: {s3_uri}")
+        
+        return s3_parts[0], s3_parts[1]  # bucket, key
+
+    def extract_model_from_s3_file_path(self, s3_uri: str, optional_params: dict) -> str:
+        """
+        Extract model ID from S3 file path.
+        
+        The Bedrock file transformation creates S3 objects with the model name embedded:
+        Format: s3://bucket/litellm-bedrock-files-{model}-{uuid}.jsonl
+        """
+        # Check if model is provided in optional_params first
+        if "model" in optional_params and optional_params["model"]:
+            return self.get_bedrock_model_id_from_litellm_model(optional_params["model"])
+        
+        # Extract model from S3 URI path
+        # Expected format: s3://bucket/litellm-bedrock-files-{model}-{uuid}.jsonl
+        try:
+            bucket, object_key = self.parse_s3_uri(s3_uri)
+            
+            # Extract model from object key if it follows our naming pattern
+            if object_key.startswith("litellm-bedrock-files-"):
+                # Remove prefix and suffix to get model part
+                model_part = object_key[22:]  # Remove "litellm-bedrock-files-"
+                # Find the last dash before the UUID
+                parts = model_part.split("-")
+                if len(parts) > 1:
+                    # Reconstruct model name (everything except the last UUID part and .jsonl)
+                    model_name = "-".join(parts[:-1])
+                    if model_name.endswith(".jsonl"):
+                        model_name = model_name[:-6]  # Remove .jsonl
+                    return model_name
+        except Exception:
+            pass
+        
+        # Fallback to default model
+        return "anthropic.claude-3-5-sonnet-20240620-v1:0"
+
+    def sign_aws_request(
+        self,
+        service_name: str,
+        data: Union[str, dict, "BedrockCreateBatchRequest"],
+        endpoint_url: str,
+        optional_params: dict,
+        method: str = "POST",
+    ) -> tuple:
+        """
+        Sign AWS request using Signature Version 4.
+        
+        Args:
+            service_name: AWS service name ("bedrock" or "s3")
+            data: Request data (string or dict)
+            endpoint_url: Full endpoint URL
+            optional_params: Optional parameters containing AWS credentials
+            method: HTTP method (default: POST)
+            
+        Returns:
+            Tuple of (signed_headers, signed_data)
+        """
+        try:
+            from botocore.auth import SigV4Auth
+            from botocore.awsrequest import AWSRequest
+        except ImportError:
+            raise ImportError("Missing boto3 to call bedrock. Run 'pip install boto3'.")
+
+        # Get AWS credentials using existing methods
+        aws_region_name = self._base_aws._get_aws_region_name(
+            optional_params=optional_params, model=""
+        )
+        credentials = self._base_aws.get_credentials(
+            aws_access_key_id=optional_params.get("aws_access_key_id"),
+            aws_secret_access_key=optional_params.get("aws_secret_access_key"),
+            aws_session_token=optional_params.get("aws_session_token"),
+            aws_region_name=aws_region_name,
+            aws_session_name=optional_params.get("aws_session_name"),
+            aws_profile_name=optional_params.get("aws_profile_name"),
+            aws_role_name=optional_params.get("aws_role_name"),
+            aws_web_identity_token=optional_params.get("aws_web_identity_token"),
+            aws_sts_endpoint=optional_params.get("aws_sts_endpoint"),
+        )
+        
+        # Prepare the request data
+        method_upper = method.upper()
+        if method_upper == "GET":
+            # GET requests should be signed with an empty payload
+            request_data = ""
+            headers = {}
+        else:
+            if isinstance(data, dict):
+                import json
+                request_data = json.dumps(data)
+            else:
+                request_data = data
+            # Prepare headers for non-GET requests
+            headers = {"Content-Type": "application/json"}
+        
+        # Create AWS request and sign it
+        sigv4 = SigV4Auth(credentials, service_name, aws_region_name)
+        request = AWSRequest(
+            method=method_upper, url=endpoint_url, data=request_data, headers=headers
+        )
+        sigv4.add_auth(request)
+        prepped = request.prepare()
+        
+        return dict(prepped.headers), request_data.encode('utf-8') if isinstance(request_data, str) else request_data
+
+    def generate_unique_job_name(self, model: str, prefix: str = "litellm") -> str:
+        """
+        Generate a unique job name for AWS services.
+        AWS services often have length limits, so this creates a concise name.
+        
+        Args:
+            model: Model name to include in the job name
+            prefix: Prefix for the job name
+            
+        Returns:
+            Unique job name (≤ 63 characters for Bedrock compatibility)
+        """
+        from litellm._uuid import uuid
+        unique_id = str(uuid.uuid4())[:8]
+        # Format: {prefix}-batch-{model}-{uuid}
+        # Example: litellm-batch-claude-266c398e
+        job_name = f"{prefix}-batch-{unique_id}"
+        
+        return job_name
+
+    def get_s3_bucket_and_key_from_config(
+        self, 
+        litellm_params: dict, 
+        optional_params: dict,
+        bucket_env_var: str = "AWS_S3_BUCKET_NAME",
+        key_prefix: str = "litellm"
+    ) -> tuple:
+        """
+        Get S3 bucket and generate a unique key from configuration.
+        
+        Args:
+            litellm_params: LiteLLM parameters
+            optional_params: Optional parameters
+            bucket_env_var: Environment variable name for bucket
+            key_prefix: Prefix for the S3 key
+            
+        Returns:
+            Tuple of (bucket_name, object_key)
+        """
+        import time
+        from litellm._uuid import uuid
+
+        # Get bucket name
+        bucket_name = (
+            litellm_params.get("s3_bucket_name") 
+            or optional_params.get("s3_bucket_name")
+            or os.getenv(bucket_env_var)
+        )
+        if not bucket_name:
+            raise ValueError(f"S3 bucket name is required. Set 's3_bucket_name' parameter or {bucket_env_var} env var")
+        
+        # Generate unique object key
+        timestamp = int(time.time())
+        unique_id = str(uuid.uuid4())[:8]
+        object_key = f"{key_prefix}-{timestamp}-{unique_id}"
+        
+        return bucket_name, object_key
+
+    def get_error_class(
+        self, error_message: str, status_code: int, headers: Union[Dict, httpx.Headers]
+    ) -> BaseLLMException:
+        """
+        Get Bedrock-specific error class.
+        """
+        return BedrockError(
+            status_code=status_code, 
+            message=error_message, 
+            headers=headers
+        )
