@@ -4,11 +4,13 @@ Handles embedding calls to Bedrock's `/invoke` endpoint
 
 import copy
 import json
-from typing import Any, Callable, List, Optional, Tuple, Union
+import urllib.parse
+from typing import Any, Callable, List, Optional, Tuple, Union, get_args
 
 import httpx
 
 import litellm
+from litellm.constants import BEDROCK_EMBEDDING_PROVIDERS_LITERAL
 from litellm.llms.cohere.embed.handler import embedding as cohere_embedding
 from litellm.llms.custom_httpx.http_handler import (
     AsyncHTTPHandler,
@@ -17,7 +19,11 @@ from litellm.llms.custom_httpx.http_handler import (
     get_async_httpx_client,
 )
 from litellm.secret_managers.main import get_secret
-from litellm.types.llms.bedrock import AmazonEmbeddingRequest, CohereEmbeddingRequest
+from litellm.types.llms.bedrock import (
+    AmazonEmbeddingRequest,
+    CohereEmbeddingRequest,
+    TwelveLabsMarengoEmbeddingRequest,
+)
 from litellm.types.utils import EmbeddingResponse
 
 from ..base_aws_llm import BaseAWSLLM
@@ -28,6 +34,7 @@ from .amazon_titan_multimodal_transformation import (
 )
 from .amazon_titan_v2_transformation import AmazonTitanV2Config
 from .cohere_transformation import BedrockCohereEmbeddingConfig
+from .twelvelabs_marengo_transformation import TwelveLabsMarengoEmbeddingConfig
 
 
 class BedrockEmbedding(BaseAWSLLM):
@@ -144,6 +151,44 @@ class BedrockEmbedding(BaseAWSLLM):
             raise BedrockError(status_code=408, message="Timeout error occurred.")
 
         return response.json()
+    
+    def _transform_response(
+        self, response_list: List[dict], model: str, provider: BEDROCK_EMBEDDING_PROVIDERS_LITERAL
+    ) -> Optional[EmbeddingResponse]:
+        """
+        Transforms the response from the Bedrock embedding provider to the OpenAI format.
+        """
+        returned_response: Optional[EmbeddingResponse] = None
+        if model == "amazon.titan-embed-image-v1":
+            returned_response = (
+                AmazonTitanMultimodalEmbeddingG1Config()._transform_response(
+                    response_list=response_list, model=model
+                )
+            )
+        elif model == "amazon.titan-embed-text-v1":
+            returned_response = AmazonTitanG1Config()._transform_response(
+                response_list=response_list, model=model
+            )
+        elif model == "amazon.titan-embed-text-v2:0":
+            returned_response = AmazonTitanV2Config()._transform_response(
+                response_list=response_list, model=model
+            )
+        elif provider == "twelvelabs":
+            returned_response = TwelveLabsMarengoEmbeddingConfig()._transform_response(
+                response_list=response_list, model=model
+            )
+        
+        
+        ########################################################## 
+        # Validate returned response
+        ##########################################################
+        if returned_response is None:
+            raise Exception(
+                "Unable to map model response to known provider format. model={}".format(
+                    model
+                )
+            )
+        return returned_response
 
     def _single_func_embeddings(
         self,
@@ -156,6 +201,7 @@ class BedrockEmbedding(BaseAWSLLM):
         aws_region_name: str,
         model: str,
         logging_obj: Any,
+        provider: BEDROCK_EMBEDDING_PROVIDERS_LITERAL,
         api_key: Optional[str] = None,
     ):
         responses: List[dict] = []
@@ -163,16 +209,16 @@ class BedrockEmbedding(BaseAWSLLM):
             headers = {"Content-Type": "application/json"}
             if extra_headers is not None:
                 headers = {"Content-Type": "application/json", **extra_headers}
-                
+
             prepped = self.get_request_headers(
-                 credentials=credentials,
-                 aws_region_name=aws_region_name,
-                 extra_headers=extra_headers,
-                 endpoint_url=endpoint_url,
-                 data=json.dumps(data),
-                 headers=headers,
-                 api_key=api_key
-             )
+                credentials=credentials,
+                aws_region_name=aws_region_name,
+                extra_headers=extra_headers,
+                endpoint_url=endpoint_url,
+                data=json.dumps(data),
+                headers=headers,
+                api_key=api_key,
+            )
 
             ## LOGGING
             logging_obj.pre_call(
@@ -202,32 +248,9 @@ class BedrockEmbedding(BaseAWSLLM):
 
             responses.append(response)
 
-        returned_response: Optional[EmbeddingResponse] = None
-
-        ## TRANSFORM RESPONSE ##
-        if model == "amazon.titan-embed-image-v1":
-            returned_response = (
-                AmazonTitanMultimodalEmbeddingG1Config()._transform_response(
-                    response_list=responses, model=model
-                )
-            )
-        elif model == "amazon.titan-embed-text-v1":
-            returned_response = AmazonTitanG1Config()._transform_response(
-                response_list=responses, model=model
-            )
-        elif model == "amazon.titan-embed-text-v2:0":
-            returned_response = AmazonTitanV2Config()._transform_response(
-                response_list=responses, model=model
-            )
-
-        if returned_response is None:
-            raise Exception(
-                "Unable to map model response to known provider format. model={}".format(
-                    model
-                )
-            )
-
-        return returned_response
+        return self._transform_response(
+            response_list=responses, model=model, provider=provider
+        )
 
     async def _async_single_func_embeddings(
         self,
@@ -240,6 +263,7 @@ class BedrockEmbedding(BaseAWSLLM):
         aws_region_name: str,
         model: str,
         logging_obj: Any,
+        provider: BEDROCK_EMBEDDING_PROVIDERS_LITERAL,
         api_key: Optional[str] = None,
     ):
         responses: List[dict] = []
@@ -247,16 +271,16 @@ class BedrockEmbedding(BaseAWSLLM):
             headers = {"Content-Type": "application/json"}
             if extra_headers is not None:
                 headers = {"Content-Type": "application/json", **extra_headers}
-                
+
             prepped = self.get_request_headers(
-                 credentials=credentials,
-                 aws_region_name=aws_region_name,
-                 extra_headers=extra_headers,
-                 endpoint_url=endpoint_url,
-                 data=json.dumps(data),
-                 headers=headers,
-                 api_key=api_key,
-             )
+                credentials=credentials,
+                aws_region_name=aws_region_name,
+                extra_headers=extra_headers,
+                endpoint_url=endpoint_url,
+                data=json.dumps(data),
+                headers=headers,
+                api_key=api_key,
+            )
 
             ## LOGGING
             logging_obj.pre_call(
@@ -285,33 +309,10 @@ class BedrockEmbedding(BaseAWSLLM):
             )
 
             responses.append(response)
-
-        returned_response: Optional[EmbeddingResponse] = None
-
         ## TRANSFORM RESPONSE ##
-        if model == "amazon.titan-embed-image-v1":
-            returned_response = (
-                AmazonTitanMultimodalEmbeddingG1Config()._transform_response(
-                    response_list=responses, model=model
-                )
-            )
-        elif model == "amazon.titan-embed-text-v1":
-            returned_response = AmazonTitanG1Config()._transform_response(
-                response_list=responses, model=model
-            )
-        elif model == "amazon.titan-embed-text-v2:0":
-            returned_response = AmazonTitanV2Config()._transform_response(
-                response_list=responses, model=model
-            )
-
-        if returned_response is None:
-            raise Exception(
-                "Unable to map model response to known provider format. model={}".format(
-                    model
-                )
-            )
-
-        return returned_response
+        return self._transform_response(
+            response_list=responses, model=model, provider=provider
+        )
 
     def embeddings(
         self,
@@ -333,7 +334,22 @@ class BedrockEmbedding(BaseAWSLLM):
         credentials, aws_region_name = self._load_credentials(optional_params)
 
         ### TRANSFORMATION ###
-        provider = model.split(".")[0]
+        unencoded_model_id = (
+            optional_params.pop("model_id", None) or model
+        )  # default to model if not passed
+        modelId = urllib.parse.quote(unencoded_model_id, safe="")
+        aws_region_name = self._get_aws_region_name(
+            optional_params=optional_params,
+            model=model,
+            model_id=unencoded_model_id,
+        )
+
+        provider = self.get_bedrock_embedding_provider(model)
+        if provider is None:
+            raise Exception(
+                f"Unable to determine bedrock embedding provider for model: {model}. "
+                f"Supported providers: {list(get_args(BEDROCK_EMBEDDING_PROVIDERS_LITERAL))}"
+            )
         inference_params = copy.deepcopy(optional_params)
         inference_params = {
             k: v
@@ -343,9 +359,6 @@ class BedrockEmbedding(BaseAWSLLM):
         inference_params.pop(
             "user", None
         )  # make sure user is not passed in for bedrock call
-        modelId = (
-            optional_params.pop("model_id", None) or model
-        )  # default to model if not passed
 
         data: Optional[CohereEmbeddingRequest] = None
         batch_data: Optional[List] = None
@@ -386,6 +399,15 @@ class BedrockEmbedding(BaseAWSLLM):
                         )
                     )
                 batch_data.append(transformed_request)
+        elif provider == "twelvelabs":
+            batch_data = []
+            for i in input:
+                twelvelabs_request: (
+                    TwelveLabsMarengoEmbeddingRequest
+                ) = TwelveLabsMarengoEmbeddingConfig()._transform_request(
+                    input=i, inference_params=inference_params
+                )
+                batch_data.append(twelvelabs_request)
 
         ### SET RUNTIME ENDPOINT ###
         endpoint_url, proxy_endpoint_url = self.get_runtime_endpoint(
@@ -414,8 +436,9 @@ class BedrockEmbedding(BaseAWSLLM):
                     model=model,
                     logging_obj=logging_obj,
                     api_key=api_key,
+                    provider=provider,
                 )
-            return self._single_func_embeddings(
+            returned_response = self._single_func_embeddings(
                 client=(
                     client
                     if client is not None and isinstance(client, HTTPHandler)
@@ -430,14 +453,18 @@ class BedrockEmbedding(BaseAWSLLM):
                 model=model,
                 logging_obj=logging_obj,
                 api_key=api_key,
+                provider=provider,
             )
+            if returned_response is None:
+                raise Exception("Unable to map Bedrock request to provider")
+            return returned_response
         elif data is None:
             raise Exception("Unable to map Bedrock request to provider")
 
         headers = {"Content-Type": "application/json"}
         if extra_headers is not None:
             headers = {"Content-Type": "application/json", **extra_headers}
-        
+
         prepped = self.get_request_headers(
             credentials=credentials,
             aws_region_name=aws_region_name,
