@@ -16,21 +16,20 @@ import json
 import sys
 from typing import Any, AsyncGenerator, List, Literal, Optional, Tuple, Union
 
+import httpx
 from fastapi import HTTPException
 
 import litellm
 from litellm._logging import verbose_proxy_logger
 from litellm.caching import DualCache
-from litellm.integrations.custom_guardrail import (
-    CustomGuardrail,
-    log_guardrail_information,
-)
+from litellm.integrations.custom_guardrail import CustomGuardrail
 from litellm.llms.bedrock.base_aws_llm import BaseAWSLLM
 from litellm.llms.custom_httpx.http_handler import (
     get_async_httpx_client,
     httpxSpecialProvider,
 )
 from litellm.proxy._types import UserAPIKeyAuth
+from litellm.secret_managers.main import get_secret_str
 from litellm.types.guardrails import GuardrailEventHooks
 from litellm.types.llms.openai import AllMessageValues
 from litellm.types.proxy.guardrails.guardrail_hooks.bedrock_guardrails import (
@@ -109,6 +108,7 @@ class BedrockGuardrail(CustomGuardrail, BaseAWSLLM):
         )
         self.guardrailIdentifier = guardrailIdentifier
         self.guardrailVersion = guardrailVersion
+        self.guardrail_provider = "bedrock"
 
         # store kwargs as optional_params
         self.optional_params = kwargs
@@ -117,18 +117,17 @@ class BedrockGuardrail(CustomGuardrail, BaseAWSLLM):
         """
         If True, will not raise an exception when the guardrail is blocked.
         """
-        
 
         # Set supported event hooks to include MCP hooks
-        if 'supported_event_hooks' not in kwargs:
-            kwargs['supported_event_hooks'] = [
+        if "supported_event_hooks" not in kwargs:
+            kwargs["supported_event_hooks"] = [
                 GuardrailEventHooks.pre_call,
                 GuardrailEventHooks.post_call,
                 GuardrailEventHooks.during_call,
                 GuardrailEventHooks.pre_mcp_call,
                 GuardrailEventHooks.during_mcp_call,
             ]
-        
+
         super().__init__(**kwargs)
         BaseAWSLLM.__init__(self)
 
@@ -137,9 +136,10 @@ class BedrockGuardrail(CustomGuardrail, BaseAWSLLM):
             self.guardrailIdentifier,
             self.guardrailVersion,
         )
-    
 
-    def _create_bedrock_input_content_request(self, messages: Optional[List[AllMessageValues]]) -> BedrockRequest:
+    def _create_bedrock_input_content_request(
+        self, messages: Optional[List[AllMessageValues]]
+    ) -> BedrockRequest:
         """
         Create a bedrock request for the input content - the LLM request.
         """
@@ -148,8 +148,8 @@ class BedrockGuardrail(CustomGuardrail, BaseAWSLLM):
         if messages is None:
             return bedrock_request
         for message in messages:
-            message_text_content: Optional[List[str]] = (
-                self.get_content_for_message(message=message)
+            message_text_content: Optional[List[str]] = self.get_content_for_message(
+                message=message
             )
             if message_text_content is None:
                 continue
@@ -162,7 +162,9 @@ class BedrockGuardrail(CustomGuardrail, BaseAWSLLM):
         bedrock_request["content"] = bedrock_request_content
         return bedrock_request
 
-    def _create_bedrock_output_content_request(self, response: Union[Any, ModelResponse]) -> BedrockRequest:
+    def _create_bedrock_output_content_request(
+        self, response: Union[Any, ModelResponse]
+    ) -> BedrockRequest:
         """
         Create a bedrock request for the output content - the LLM response.
         """
@@ -198,9 +200,13 @@ class BedrockGuardrail(CustomGuardrail, BaseAWSLLM):
         """
         bedrock_request: BedrockRequest = BedrockRequest(source=source)
         if source == "INPUT":
-            bedrock_request = self._create_bedrock_input_content_request(messages=messages)
+            bedrock_request = self._create_bedrock_input_content_request(
+                messages=messages
+            )
         elif source == "OUTPUT":
-            bedrock_request = self._create_bedrock_output_content_request(response=response)
+            bedrock_request = self._create_bedrock_output_content_request(
+                response=response
+            )
         return bedrock_request
 
     #### CALL HOOKS - proxy only ####
@@ -248,62 +254,105 @@ class BedrockGuardrail(CustomGuardrail, BaseAWSLLM):
         data: dict,
         optional_params: dict,
         aws_region_name: str,
+        api_key: Optional[str] = None,
         extra_headers: Optional[dict] = None,
     ):
-        try:
-            from botocore.auth import SigV4Auth
-            from botocore.awsrequest import AWSRequest
-        except ImportError:
-            raise ImportError("Missing boto3 to call bedrock. Run 'pip install boto3'.")
-
-        sigv4 = SigV4Auth(credentials, "bedrock", aws_region_name)
-        api_base = f"https://bedrock-runtime.{aws_region_name}.amazonaws.com/guardrail/{self.guardrailIdentifier}/version/{self.guardrailVersion}/apply"
-
-        encoded_data = json.dumps(data).encode("utf-8")
         headers = {"Content-Type": "application/json"}
         if extra_headers is not None:
             headers = {"Content-Type": "application/json", **extra_headers}
 
-        request = AWSRequest(
-            method="POST", url=api_base, data=encoded_data, headers=headers
+        aws_bedrock_runtime_endpoint = self.optional_params.get(
+            "aws_bedrock_runtime_endpoint", None
         )
-        sigv4.add_auth(request)
-        if (
-            extra_headers is not None and "Authorization" in extra_headers
-        ):  # prevent sigv4 from overwriting the auth header
-            request.headers["Authorization"] = extra_headers["Authorization"]
+        _, proxy_endpoint_url = self.get_runtime_endpoint(
+            api_base=None,
+            aws_bedrock_runtime_endpoint=aws_bedrock_runtime_endpoint,
+            aws_region_name=aws_region_name,
+        )
+        proxy_endpoint_url = f"{proxy_endpoint_url}/guardrail/{self.guardrailIdentifier}/version/{self.guardrailVersion}/apply"
+        # api_base = f"https://bedrock-runtime.{aws_region_name}.amazonaws.com/guardrail/{self.guardrailIdentifier}/version/{self.guardrailVersion}/apply"
+        encoded_data = json.dumps(data).encode("utf-8")
 
+        # first check api-key, if none, fall back to sigV4
+        if api_key is not None:
+            aws_bearer_token: Optional[str] = api_key
+        else:
+            aws_bearer_token = get_secret_str("AWS_BEARER_TOKEN_BEDROCK")
+
+        if aws_bearer_token:
+            try:
+                from botocore.awsrequest import AWSRequest
+            except ImportError:
+                raise ImportError(
+                    "Missing boto3 to call bedrock. Run 'pip install boto3'."
+                )
+            headers["Authorization"] = f"Bearer {aws_bearer_token}"
+            request = AWSRequest(
+                method="POST",
+                url=proxy_endpoint_url,
+                data=encoded_data,
+                headers=headers,
+            )
+        else:
+            try:
+                from botocore.auth import SigV4Auth
+                from botocore.awsrequest import AWSRequest
+            except ImportError:
+                raise ImportError(
+                    "Missing boto3 to call bedrock. Run 'pip install boto3'."
+                )
+
+            sigv4 = SigV4Auth(credentials, "bedrock", aws_region_name)
+            request = AWSRequest(
+                method="POST",
+                url=proxy_endpoint_url,
+                data=encoded_data,
+                headers=headers,
+            )
+            sigv4.add_auth(request)
+            if (
+                extra_headers is not None and "Authorization" in extra_headers
+            ):  # prevent sigv4 from overwriting the auth header
+                request.headers["Authorization"] = extra_headers["Authorization"]
         prepped_request = request.prepare()
 
         return prepped_request
 
     async def make_bedrock_api_request(
-        self, 
+        self,
         source: Literal["INPUT", "OUTPUT"],
         messages: Optional[List[AllMessageValues]] = None,
         response: Optional[Union[Any, litellm.ModelResponse]] = None,
-        request_data: Optional[dict] = None
+        request_data: Optional[dict] = None,
     ) -> BedrockGuardrailResponse:
+        from datetime import datetime
+
+        start_time = datetime.now()
         credentials, aws_region_name = self._load_credentials()
         bedrock_request_data: dict = dict(
             self.convert_to_bedrock_format(
-                source=source, 
-                messages=messages, 
-                response=response
+                source=source, messages=messages, response=response
             )
         )
         bedrock_guardrail_response: BedrockGuardrailResponse = (
             BedrockGuardrailResponse()
         )
+        api_key: Optional[str] = None
         if request_data:
             bedrock_request_data.update(
-                self.get_guardrail_dynamic_request_body_params(request_data=request_data)
+                self.get_guardrail_dynamic_request_body_params(
+                    request_data=request_data
+                )
             )
+            if request_data.get("api_key") is not None:
+                api_key = request_data["api_key"]
+
         prepared_request = self._prepare_request(
             credentials=credentials,
             data=bedrock_request_data,
             optional_params=self.optional_params,
             aws_region_name=aws_region_name,
+            api_key=api_key,
         )
         verbose_proxy_logger.debug(
             "Bedrock AI request body: %s, url %s, headers: %s",
@@ -312,14 +361,29 @@ class BedrockGuardrail(CustomGuardrail, BaseAWSLLM):
             prepared_request.headers,
         )
 
-        response = await self.async_handler.post(
+        httpx_response = await self.async_handler.post(
             url=prepared_request.url,
             data=prepared_request.body,  # type: ignore
             headers=prepared_request.headers,  # type: ignore
         )
-        if response.status_code == 200:
+        #########################################################
+        # Add guardrail information to request trace
+        #########################################################
+        self.add_standard_logging_guardrail_information_to_request_data(
+            guardrail_provider=self.guardrail_provider,
+            guardrail_json_response=httpx_response.json(),
+            request_data=request_data or {},
+            guardrail_status=self._get_bedrock_guardrail_response_status(
+                response=httpx_response
+            ),
+            start_time=start_time.timestamp(),
+            end_time=datetime.now().timestamp(),
+            duration=(datetime.now() - start_time).total_seconds(),
+        )
+        #########################################################
+        if httpx_response.status_code == 200:
             # check if the response was flagged
-            _json_response = response.json()
+            _json_response = httpx_response.json()
             redacted_response = _redact_pii_matches(_json_response)
             verbose_proxy_logger.debug("Bedrock AI response : %s", redacted_response)
             bedrock_guardrail_response = BedrockGuardrailResponse(**_json_response)
@@ -332,14 +396,60 @@ class BedrockGuardrail(CustomGuardrail, BaseAWSLLM):
         else:
             verbose_proxy_logger.error(
                 "Bedrock AI: error in response. Status code: %s, response: %s",
-                response.status_code,
-                response.text,
+                httpx_response.status_code,
+                httpx_response.text,
             )
 
         return bedrock_guardrail_response
-    
 
-    def _get_http_exception_for_blocked_guardrail(self, response: BedrockGuardrailResponse) -> HTTPException:
+    def _check_bedrock_response_for_exception(self, response) -> bool:
+        """
+        Return True if the Bedrock ApplyGuardrail response indicates an exception.
+
+        Works with real httpx.Response objects and MagicMock responses used in tests.
+        """
+        payload = None
+
+        try:
+            json_method = getattr(response, "json", None)
+            if callable(json_method):
+                payload = json_method()
+        except Exception:
+            payload = None
+
+        if payload is None:
+            try:
+                raw = getattr(response, "content", None)
+                if isinstance(raw, (bytes, bytearray)):
+                    payload = json.loads(raw.decode("utf-8"))
+                else:
+                    text = getattr(response, "text", None)
+                    if isinstance(text, str):
+                        payload = json.loads(text)
+            except Exception:
+                # Can't parse -> assume no explicit Exception marker
+                return False
+
+        if not isinstance(payload, dict):
+            return False
+
+        return "Exception" in payload.get("Output", {}).get("__type", "")
+
+    def _get_bedrock_guardrail_response_status(
+        self, response: httpx.Response
+    ) -> Literal["success", "failure"]:
+        """
+        Get the status of the bedrock guardrail response.
+        """
+        if response.status_code == 200:
+            if self._check_bedrock_response_for_exception(response):
+                return "failure"
+            return "success"
+        return "failure"
+
+    def _get_http_exception_for_blocked_guardrail(
+        self, response: BedrockGuardrailResponse
+    ) -> HTTPException:
         """
         Get the HTTP exception for a blocked guardrail.
         """
@@ -351,17 +461,15 @@ class BedrockGuardrail(CustomGuardrail, BaseAWSLLM):
             for output in outputs:
                 if output.get("text"):
                     bedrock_guardrail_output_text += output.get("text") or ""
-                
-        
+
         return HTTPException(
             status_code=400,
             detail={
-                "error": "Violated guardrail policy", 
+                "error": "Violated guardrail policy",
                 "bedrock_guardrail_response": bedrock_guardrail_output_text,
-            }
+            },
         )
 
-
     def _should_raise_guardrail_blocked_exception(
         self, response: BedrockGuardrailResponse
     ) -> bool:
@@ -374,7 +482,7 @@ class BedrockGuardrail(CustomGuardrail, BaseAWSLLM):
         # if user opted into masking, return False. since we'll use the masked output from the guardrail
         if self.mask_request_content or self.mask_response_content:
             return False
-        
+
         if self.disable_exception_on_block is True:
             return False
 
@@ -442,7 +550,6 @@ class BedrockGuardrail(CustomGuardrail, BaseAWSLLM):
         # This means all actions were ANONYMIZED or NONE, so don't raise exception
         return False
 
-    @log_guardrail_information
     async def async_pre_call_hook(
         self,
         user_api_key_dict: UserAPIKeyAuth,
@@ -501,10 +608,8 @@ class BedrockGuardrail(CustomGuardrail, BaseAWSLLM):
         add_guardrail_to_applied_guardrails_header(
             request_data=data, guardrail_name=self.guardrail_name
         )
-
         return data
 
-    @log_guardrail_information
     async def async_moderation_hook(
         self,
         data: dict,
@@ -561,7 +666,6 @@ class BedrockGuardrail(CustomGuardrail, BaseAWSLLM):
 
         return data
 
-    @log_guardrail_information
     async def async_post_call_success_hook(
         self,
         data: dict,
@@ -592,9 +696,7 @@ class BedrockGuardrail(CustomGuardrail, BaseAWSLLM):
         ########## 1. Make parallel Bedrock API requests ##########
         #########################################################
         output_content_bedrock = await self.make_bedrock_api_request(
-            source="OUTPUT", 
-            response=response,
-            request_data=data
+            source="OUTPUT", response=response, request_data=data
         )  # Only response
 
         #########################################################
@@ -690,16 +792,16 @@ class BedrockGuardrail(CustomGuardrail, BaseAWSLLM):
             ###################################################################
             # Create tasks for parallel execution
             input_task = self.make_bedrock_api_request(
-                source="INPUT", messages=request_data.get("messages"), request_data=request_data
+                source="INPUT",
+                messages=request_data.get("messages"),
+                request_data=request_data,
             )  # Only input messages
             output_task = self.make_bedrock_api_request(
                 source="OUTPUT", response=assembled_model_response
             )  # Only response
 
             # Execute both requests in parallel
-            _, output_guardrail_response = await asyncio.gather(
-                input_task, output_task
-            )
+            _, output_guardrail_response = await asyncio.gather(input_task, output_task)
 
             #########################################################################
             ########## 2. Apply masking to response with output guardrail response ##########
@@ -852,7 +954,7 @@ class BedrockGuardrail(CustomGuardrail, BaseAWSLLM):
     ) -> None:
         """
         Apply masked content from bedrock guardrail to the response object.
-        
+
         Args:
             response: The response object to modify
             bedrock_guardrail_response: Response from Bedrock guardrail containing masked content
@@ -863,7 +965,9 @@ class BedrockGuardrail(CustomGuardrail, BaseAWSLLM):
         )
 
         if not masked_texts:
-            verbose_proxy_logger.debug("No masked outputs found, skipping response masking")
+            verbose_proxy_logger.debug(
+                "No masked outputs found, skipping response masking"
+            )
             return
 
         verbose_proxy_logger.debug(
@@ -883,13 +987,13 @@ class BedrockGuardrail(CustomGuardrail, BaseAWSLLM):
     ) -> None:
         """
         Apply masked texts to a ModelResponse object.
-        
+
         Args:
             response: The ModelResponse object to modify in-place
             masked_texts: List of masked text strings from guardrail
         """
         masking_index = 0
-        
+
         for choice in response.choices:
             if isinstance(choice, Choices):
                 # For chat completions
