@@ -21,11 +21,11 @@ from litellm.integrations.custom_guardrail import (
     CustomGuardrail,
     log_guardrail_information,
 )
-from litellm.llms.vertex_ai.vertex_llm_base import VertexBase
 from litellm.llms.custom_httpx.http_handler import (
     get_async_httpx_client,
     httpxSpecialProvider,
 )
+from litellm.llms.vertex_ai.vertex_llm_base import VertexBase
 from litellm.proxy._types import UserAPIKeyAuth
 from litellm.types.guardrails import GuardrailEventHooks
 from litellm.types.utils import (
@@ -58,7 +58,7 @@ class ModelArmorGuardrail(CustomGuardrail, VertexBase):
         # Initialize parent classes first
         super().__init__(**kwargs)
         VertexBase.__init__(self)
-        
+
         # Then set our attributes (this ensures project_id is not overwritten)
         self.async_handler = get_async_httpx_client(
             llm_provider=httpxSpecialProvider.GuardrailCallback
@@ -88,20 +88,18 @@ class ModelArmorGuardrail(CustomGuardrail, VertexBase):
     def _create_sanitize_request(
         self, content: str, source: Literal["user_prompt", "model_response"]
     ) -> dict:
-        """Create request body for Model Armor API."""
+        """Create request body for Model Armor API with correct camelCase field names."""
         if source == "user_prompt":
-            return {"user_prompt_data": {"text": content}}
+            return {"userPromptData": {"text": content}}
         else:
-            return {"model_response_data": {"text": content}}
-
-
+            return {"modelResponseData": {"text": content}}
 
     def _extract_content_from_response(
         self, response: Union[Any, ModelResponse]
     ) -> str:
         """
         Extract text content from model response.
-        
+
         Returns empty string for non-text responses (TTS, images, etc.) to skip guardrail processing.
         """
         from litellm.litellm_core_utils.prompt_templates.common_utils import (
@@ -121,11 +119,16 @@ class ModelArmorGuardrail(CustomGuardrail, VertexBase):
 
     async def make_model_armor_request(
         self,
-        content: str,
-        source: Literal["user_prompt", "model_response"],
+        content: Optional[str] = None,
+        source: Literal["user_prompt", "model_response"] = "user_prompt",
         request_data: Optional[dict] = None,
+        file_bytes: Optional[bytes] = None,
+        file_type: Optional[str] = None,
     ) -> dict:
-        """Make request to Model Armor API."""
+        """
+        Make request to Model Armor API. Supports both text and file prompt sanitization.
+        If file_bytes and file_type are provided, file prompt sanitization is performed.
+        """
         # Get access token using VertexBase auth
         access_token, resolved_project_id = await self._ensure_access_token_async(
             credentials=self.credentials,
@@ -145,7 +148,14 @@ class ModelArmorGuardrail(CustomGuardrail, VertexBase):
             url = f"{endpoint}/v1/projects/{self.project_id}/locations/{self.location}/templates/{self.template_id}:sanitizeModelResponse"
 
         # Create request body
-        body = self._create_sanitize_request(content, source)
+        if file_bytes is not None and file_type is not None:
+            body = self.sanitize_file_prompt(file_bytes, file_type, source)
+        elif content is not None:
+            body = self._create_sanitize_request(content, source)
+        else:
+            raise ValueError(
+                "Either content or file_bytes and file_type must be provided."
+            )
 
         # Set headers
         headers = {
@@ -191,24 +201,147 @@ class ModelArmorGuardrail(CustomGuardrail, VertexBase):
             return await json_response
         return json_response
 
-    def _should_block_content(self, armor_response: dict) -> bool:
-        """Check if Model Armor response indicates content should be blocked."""
-        # Model Armor may return different response structures
-        # This is a basic implementation - adjust based on actual API response
-        if armor_response.get("blocked", False):
-            return True
+    def sanitize_file_prompt(
+        self, file_bytes: bytes, file_type: str, source: str = "user_prompt"
+    ) -> dict:
+        """
+        Helper to build the request body for file prompt sanitization for Model Armor.
+        file_type should be one of: PLAINTEXT_UTF8, PDF, WORD_DOCUMENT, EXCEL_DOCUMENT, POWERPOINT_DOCUMENT, TXT, CSV
+        Returns the request body dict.
+        """
+        import base64
 
-        # Check for sanitization actions
-        if armor_response.get("action") == "BLOCK":
-            return True
+        base64_data = base64.b64encode(file_bytes).decode("utf-8")
+        if source == "user_prompt":
+            return {
+                "userPromptData": {
+                    "byteItem": {"byteDataType": file_type, "byteData": base64_data}
+                }
+            }
+        else:
+            return {
+                "modelResponseData": {
+                    "byteItem": {"byteDataType": file_type, "byteData": base64_data}
+                }
+            }
 
+    def _should_block_content(self, armor_response: dict, allow_sanitization: bool = False) -> bool:
+        """Check if Model Armor response indicates content should be blocked, including both inspectResult and deidentifyResult."""
+        sanitization_result = armor_response.get("sanitizationResult", {})
+        filter_results = sanitization_result.get("filterResults", {})
+
+        # filterResults can be a dict (named keys) or a list (array of filter result dicts)
+        filter_result_items = []
+        if isinstance(filter_results, dict):
+            filter_result_items = list(filter_results.values())
+        elif isinstance(filter_results, list):
+            filter_result_items = filter_results
+
+        for filt in filter_result_items:
+            # Check RAI, PI/Jailbreak, Malicious URI, CSAM, Virus scan as before
+            if filt.get("raiFilterResult", {}).get("matchState") == "MATCH_FOUND":
+                return True
+            if (
+                filt.get("piAndJailbreakFilterResult", {}).get("matchState")
+                == "MATCH_FOUND"
+            ):
+                return True
+            if (
+                filt.get("maliciousUriFilterResult", {}).get("matchState")
+                == "MATCH_FOUND"
+            ):
+                return True
+            if (
+                filt.get("csamFilterFilterResult", {}).get("matchState")
+                == "MATCH_FOUND"
+            ):
+                return True
+            if filt.get("virusScanFilterResult", {}).get("matchState") == "MATCH_FOUND":
+                return True
+            # Check sdpFilterResult for both inspectResult and deidentifyResult
+            sdp = filt.get("sdpFilterResult")
+            if sdp:
+                if sdp.get("inspectResult", {}).get("matchState") == "MATCH_FOUND":
+                    return True
+                # Only block on deidentifyResult if sanitization is not allowed
+                if sdp.get("deidentifyResult", {}).get("matchState") == "MATCH_FOUND":
+                    if not allow_sanitization:
+                        return True
+        # Fallback dict code removed; all cases handled above
         return False
 
     def _get_sanitized_content(self, armor_response: dict) -> Optional[str]:
-        """Extract sanitized content from Model Armor response."""
-        # This depends on the actual Model Armor API response structure
-        # Adjust based on documentation
-        return armor_response.get("sanitized_text") or armor_response.get("text")
+        """
+        Get the sanitized content from a Model Armor response, if available.
+        Looks for sanitized text in deidentifyResult, and falls back to root-level fields if not found.
+        """
+        result = armor_response.get("sanitizationResult", {})
+        filter_results = result.get("filterResults", {})
+
+        # filterResults can be a dict (single filter) or a list (multiple filters)
+        filters = (
+            list(filter_results.values())
+            if isinstance(filter_results, dict)
+            else filter_results
+            if isinstance(filter_results, list)
+            else []
+        )
+
+        # Prefer sanitized text from deidentifyResult if present
+        for filter_entry in filters:
+            sdp = filter_entry.get("sdpFilterResult")
+            if sdp:
+                deid = sdp.get("deidentifyResult", {})
+                sanitized = deid.get("data", {}).get("text", "")
+                # If Model Armor found something and returned a sanitized version, use it
+                if deid.get("matchState") == "MATCH_FOUND" and sanitized:
+                    return sanitized
+
+        # If no deidentifyResult, optionally check for inspectResult (rare, but could have findings)
+        for filter_entry in filters:
+            sdp = filter_entry.get("sdpFilterResult")
+            if sdp:
+                inspect = sdp.get("inspectResult", {})
+                # If Model Armor flagged something but didn't sanitize, return None
+                if inspect.get("matchState") == "MATCH_FOUND":
+                    return None
+
+        # Fallback: if Model Armor put sanitized text at the root, use it
+        return armor_response.get("sanitizedText") or armor_response.get("text")
+
+    def _process_response(
+        self,
+        response: Optional[dict],
+        request_data: dict,
+        start_time: Optional[float] = None,
+        end_time: Optional[float] = None,
+        duration: Optional[float] = None,
+    ):
+        """
+        Override to store only the Model Armor API response, not the entire data dict.
+        This prevents circular references in logging.
+        """
+        # Retrieve the Model Armor response & status stored on the per-request `metadata` object.
+        metadata = (
+            request_data.get("metadata", {}) if isinstance(request_data, dict) else {}
+        )
+
+        guardrail_response = metadata.get("_model_armor_response", {})
+
+        # Determine status – default to "success" but prefer the explicit value if present.
+        guardrail_status: Literal["success", "failure", "blocked"] = metadata.get(
+            "_model_armor_status", "success"
+        )  # type: ignore
+
+        self.add_standard_logging_guardrail_information_to_request_data(
+            guardrail_json_response=guardrail_response,
+            request_data=request_data,
+            guardrail_status=guardrail_status,  # type: ignore
+            duration=duration,
+            start_time=start_time,
+            end_time=end_time,
+        )
+        return response
 
     @log_guardrail_information
     async def async_pre_call_hook(
@@ -263,8 +396,26 @@ class ModelArmorGuardrail(CustomGuardrail, VertexBase):
                 request_data=data,
             )
 
+            # Store the armor response for logging
+            # Attach Model Armor response + evaluation status directly to the per-request metadata to avoid
+            #   race-conditions between concurrent requests which share the same guardrail instance.
+            #   This ensures each request logs its own Model Armor response instead of a potentially stale value
+            #   overwritten by another coroutine.
+            if isinstance(data, dict):
+                metadata = data.setdefault(
+                    "metadata", {}
+                )  # ensures metadata exists and is unique per request
+                metadata["_model_armor_response"] = armor_response
+                # Pre-compute guardrail status for downstream logging. A blocked response will eventually raise
+                #   an HTTPException, however in scenarios where the caller decides to ignore the exception (e.g.
+                #   fail_on_error=False) we still want the correct status reflected.
+                metadata["_model_armor_status"] = (
+                    "blocked"
+                    if self._should_block_content(armor_response, allow_sanitization=self.mask_request_content)
+                    else "success"
+                )
             # Check if content should be blocked
-            if self._should_block_content(armor_response):
+            if self._should_block_content(armor_response, allow_sanitization=self.mask_request_content):
                 raise HTTPException(
                     status_code=400,
                     detail={
@@ -339,8 +490,18 @@ class ModelArmorGuardrail(CustomGuardrail, VertexBase):
                 request_data=data,
             )
 
+            # Attach Model Armor response & status to this request's metadata to prevent race conditions
+            if isinstance(data, dict):
+                metadata = data.setdefault("metadata", {})
+                metadata["_model_armor_response"] = armor_response
+                metadata["_model_armor_status"] = (
+                    "blocked"
+                    if self._should_block_content(armor_response, allow_sanitization=self.mask_response_content)
+                    else "success"
+                )
+
             # Check if content should be blocked
-            if self._should_block_content(armor_response):
+            if self._should_block_content(armor_response, allow_sanitization=self.mask_response_content):
                 raise HTTPException(
                     status_code=400,
                     detail={
@@ -406,6 +567,16 @@ class ModelArmorGuardrail(CustomGuardrail, VertexBase):
                         request_data=request_data,
                     )
 
+                    # Attach Model Armor response & status to this request's metadata to avoid race conditions
+                    if isinstance(request_data, dict):
+                        metadata = request_data.setdefault("metadata", {})
+                        metadata["_model_armor_response"] = armor_response
+                        metadata["_model_armor_status"] = (
+                            "blocked"
+                            if self._should_block_content(armor_response)
+                            else "success"
+                        )
+
                     # Check if blocked
                     if self._should_block_content(armor_response):
                         raise HTTPException(
