@@ -3,7 +3,6 @@ import asyncio
 import copy
 import json
 import traceback
-import uuid
 from base64 import b64encode
 from datetime import datetime
 from typing import Dict, List, Optional, Tuple, Union
@@ -25,6 +24,7 @@ from starlette.datastructures import UploadFile as StarletteUploadFile
 
 import litellm
 from litellm._logging import verbose_proxy_logger
+from litellm._uuid import uuid
 from litellm.constants import MAXIMUM_TRACEBACK_LINES_TO_LOG
 from litellm.integrations.custom_logger import CustomLogger
 from litellm.litellm_core_utils.litellm_logging import Logging as LiteLLMLoggingObj
@@ -57,6 +57,9 @@ router = APIRouter()
 
 pass_through_endpoint_logging = PassThroughEndpointLogging()
 
+# Global registry to track registered pass-through routes and prevent memory leaks
+_registered_pass_through_routes: Dict[str, Dict[str, str]] = {}
+
 
 def get_response_body(response: httpx.Response) -> Optional[dict]:
     try:
@@ -261,7 +264,7 @@ async def chat_completion_pass_through_endpoint(  # noqa: PLR0915
             )
         )
 
-        verbose_proxy_logger.info("\nResponse from Litellm:\n{}".format(response))
+        verbose_proxy_logger.debug("\nResponse from Litellm:\n{}".format(response))
         return response
     except Exception as e:
         await proxy_logging_obj.post_call_failure_hook(
@@ -314,6 +317,12 @@ class HttpPassThroughEndpointHelpers(BasePassthroughUtils):
             return EndpointType.VERTEX_AI
         elif parsed_url.hostname == "api.anthropic.com":
             return EndpointType.ANTHROPIC
+        elif (
+            parsed_url.hostname == "api.openai.com"
+            or parsed_url.hostname == "openai.azure.com"
+            or (parsed_url.hostname and "openai.com" in parsed_url.hostname)
+        ):
+            return EndpointType.OPENAI
         return EndpointType.GENERIC
 
     @staticmethod
@@ -465,6 +474,13 @@ class HttpPassThroughEndpointHelpers(BasePassthroughUtils):
                 user_api_key_team_alias=user_api_key_dict.team_alias,
                 user_api_key_end_user_id=user_api_key_dict.end_user_id,
                 user_api_key_request_route=user_api_key_dict.request_route,
+                user_api_key_spend=user_api_key_dict.spend,
+                user_api_key_max_budget=user_api_key_dict.max_budget,
+                user_api_key_budget_reset_at=(
+                    user_api_key_dict.budget_reset_at.isoformat()
+                    if user_api_key_dict.budget_reset_at
+                    else None
+                ),
             )
         )
 
@@ -484,7 +500,7 @@ class HttpPassThroughEndpointHelpers(BasePassthroughUtils):
 
         kwargs = {
             "litellm_params": {
-                **litellm_params_in_body,
+                **litellm_params_in_body,  # type: ignore
                 "metadata": _metadata,
                 "proxy_server_request": {
                     "url": str(request.url),
@@ -532,6 +548,19 @@ class HttpPassThroughEndpointHelpers(BasePassthroughUtils):
 
         return base_target + subpath
 
+    @staticmethod
+    def _update_stream_param_based_on_request_body(
+        parsed_body: dict,
+        stream: Optional[bool] = None,
+    ) -> Optional[bool]:
+        """
+        If stream is provided in the request body, use it.
+        Otherwise, use the stream parameter passed to the `pass_through_request` function
+        """
+        if "stream" in parsed_body:
+            return parsed_body.get("stream", stream)
+        return stream
+
 
 async def pass_through_request(  # noqa: PLR0915
     request: Request,
@@ -686,6 +715,13 @@ async def pass_through_request(  # noqa: PLR0915
                 "headers": headers,
             },
         )
+        stream = (
+            HttpPassThroughEndpointHelpers._update_stream_param_based_on_request_body(
+                parsed_body=_parsed_body,
+                stream=stream,
+            )
+        )
+
         if stream:
             req = async_client.build_request(
                 "POST",
@@ -890,8 +926,7 @@ def create_pass_through_route(
     cost_per_request: Optional[float] = None,
 ):
     # check if target is an adapter.py or a url
-    import uuid
-
+    from litellm._uuid import uuid
     from litellm.proxy.types_utils.utils import get_instance_fn
 
     try:
@@ -970,8 +1005,19 @@ class InitPassThroughEndpointHelpers:
         merge_query_params: Optional[bool],
         dependencies: Optional[List],
         cost_per_request: Optional[float],
+        endpoint_id: str,
     ):
         """Add exact path route for pass-through endpoint"""
+        route_key = f"{endpoint_id}:exact:{path}"
+
+        # Check if this exact route is already registered
+        if route_key in _registered_pass_through_routes:
+            verbose_proxy_logger.debug(
+                "Skipping duplicate exact pass through endpoint: %s (already registered)",
+                path,
+            )
+            return
+
         verbose_proxy_logger.debug(
             "adding exact pass through endpoint: %s, dependencies: %s",
             path,
@@ -993,6 +1039,13 @@ class InitPassThroughEndpointHelpers:
             dependencies=dependencies,
         )
 
+        # Register the route to prevent duplicates
+        _registered_pass_through_routes[route_key] = {
+            "endpoint_id": endpoint_id,
+            "path": path,
+            "type": "exact",
+        }
+
     @staticmethod
     def add_subpath_route(
         app: FastAPI,
@@ -1003,9 +1056,20 @@ class InitPassThroughEndpointHelpers:
         merge_query_params: Optional[bool],
         dependencies: Optional[List],
         cost_per_request: Optional[float],
+        endpoint_id: str,
     ):
         """Add wildcard route for sub-paths"""
         wildcard_path = f"{path}/{{subpath:path}}"
+        route_key = f"{endpoint_id}:subpath:{path}"
+
+        # Check if this subpath route is already registered
+        if route_key in _registered_pass_through_routes:
+            verbose_proxy_logger.debug(
+                "Skipping duplicate wildcard pass through endpoint: %s (already registered)",
+                wildcard_path,
+            )
+            return
+
         verbose_proxy_logger.debug(
             "adding wildcard pass through endpoint: %s, dependencies: %s",
             wildcard_path,
@@ -1028,6 +1092,27 @@ class InitPassThroughEndpointHelpers:
             dependencies=dependencies,
         )
 
+        # Register the route to prevent duplicates
+        _registered_pass_through_routes[route_key] = {
+            "endpoint_id": endpoint_id,
+            "path": path,
+            "type": "subpath",
+        }
+
+    @staticmethod
+    def remove_endpoint_routes(endpoint_id: str):
+        """Remove all routes for a specific endpoint ID from the registry"""
+        keys_to_remove = [
+            key
+            for key, value in _registered_pass_through_routes.items()
+            if value["endpoint_id"] == endpoint_id
+        ]
+        for key in keys_to_remove:
+            del _registered_pass_through_routes[key]
+            verbose_proxy_logger.debug(
+                "Removed pass-through route from registry: %s", key
+            )
+
 
 async def initialize_pass_through_endpoints(
     pass_through_endpoints: Union[List[Dict], List[PassThroughGenericEndpoint]],
@@ -1041,7 +1126,7 @@ async def initialize_pass_through_endpoints(
     Returns:
         None
     """
-    import uuid
+    from litellm._uuid import uuid
 
     verbose_proxy_logger.debug("initializing pass through endpoints")
     from litellm.proxy._types import CommonProxyErrors, LiteLLMRoutes
@@ -1055,6 +1140,9 @@ async def initialize_pass_through_endpoints(
         if endpoint.get("id") is None:
             endpoint["id"] = str(uuid.uuid4())
 
+        # Get the endpoint_id as a string (guaranteed to be set at this point)
+        endpoint_id: str = endpoint["id"]
+
         _target = endpoint.get("target", None)
         _path: Optional[str] = endpoint.get("path", None)
         if _path is None:
@@ -1082,7 +1170,7 @@ async def initialize_pass_through_endpoints(
 
         # Add exact path route
         verbose_proxy_logger.debug(
-            "Initializing pass through endpoint: %s (ID: %s)", _path, endpoint.get("id")
+            "Initializing pass through endpoint: %s (ID: %s)", _path, endpoint_id
         )
         InitPassThroughEndpointHelpers.add_exact_path_route(
             app=app,
@@ -1093,6 +1181,7 @@ async def initialize_pass_through_endpoints(
             merge_query_params=_merge_query_params,
             dependencies=_dependencies,
             cost_per_request=endpoint.get("cost_per_request", None),
+            endpoint_id=endpoint_id,
         )
 
         # Add wildcard route for sub-paths
@@ -1106,10 +1195,11 @@ async def initialize_pass_through_endpoints(
                 merge_query_params=_merge_query_params,
                 dependencies=_dependencies,
                 cost_per_request=endpoint.get("cost_per_request", None),
+                endpoint_id=endpoint_id,
             )
 
         verbose_proxy_logger.debug(
-            "Added new pass through endpoint: %s (ID: %s)", _path, endpoint.get("id")
+            "Added new pass through endpoint: %s (ID: %s)", _path, endpoint_id
         )
 
 
@@ -1250,6 +1340,9 @@ async def update_pass_through_endpoints(
     # Update the list
     pass_through_endpoint_data[endpoint_index] = endpoint_dict
 
+    # Remove old routes from registry before they get re-registered
+    InitPassThroughEndpointHelpers.remove_endpoint_routes(endpoint_id)
+
     ## Update db
     updated_data = ConfigFieldUpdate(
         field_name="pass_through_endpoints",
@@ -1276,8 +1369,7 @@ async def create_pass_through_endpoints(
     """
     Create new pass-through endpoint
     """
-    import uuid
-
+    from litellm._uuid import uuid
     from litellm.proxy.proxy_server import (
         get_config_general_settings,
         update_config_general_settings,
@@ -1394,6 +1486,9 @@ async def delete_pass_through_endpoints(
     pass_through_endpoint_data.pop(endpoint_index)
     response_obj = found_endpoint
 
+    # Remove routes from registry
+    InitPassThroughEndpointHelpers.remove_endpoint_routes(endpoint_id)
+
     ## Update db
     updated_data = ConfigFieldUpdate(
         field_name="pass_through_endpoints",
