@@ -1,7 +1,7 @@
 #### CRUD ENDPOINTS for UI Settings #####
-from typing import Any, Dict, List, Union
+from typing import Any, Dict, List, Union, Optional
 
-from fastapi import APIRouter, Depends, HTTPException
+from fastapi import APIRouter, Depends, HTTPException, UploadFile, File
 
 import litellm
 from litellm._logging import verbose_proxy_logger
@@ -19,6 +19,16 @@ class IPAddress(BaseModel):
     ip: str
 
 
+class UIThemeConfig(BaseModel):
+    """Configuration for UI theme customization"""
+    
+    # Logo configuration
+    logo_url: Optional[str] = Field(
+        default=None,
+        description="URL or path to custom logo image. Can be a local file path or HTTP/HTTPS URL"
+    )
+
+
 class SettingsResponse(BaseModel):
     """Base response model for settings with values and schema information"""
 
@@ -47,6 +57,12 @@ class DefaultTeamSettingsResponse(SettingsResponse):
     pass
 
 
+class UIThemeSettingsResponse(SettingsResponse):
+    """Response model for UI theme settings"""
+
+    pass
+
+
 @router.get(
     "/get/allowed_ips",
     tags=["Budget & Spend Tracking"],
@@ -257,14 +273,20 @@ async def update_default_team_member_budget(
     for team in teams:
         team_id = team.team_id
         max_budget_in_team = team.max_budget_in_team
-        await update_team(
-            data=UpdateTeamRequest(
-                team_id=team_id,
-                team_member_budget=max_budget_in_team,
-            ),
-            user_api_key_dict=user_api_key_dict,
-            http_request=Request(scope={"type": "http"}),
-        )
+        try:
+            await update_team(
+                data=UpdateTeamRequest(
+                    team_id=team_id,
+                    team_member_budget=max_budget_in_team,
+                ),
+                user_api_key_dict=user_api_key_dict,
+                http_request=Request(scope={"type": "http"}),
+            )
+        except Exception as e:
+            verbose_proxy_logger.info(
+                f"Error updating team {team_id} with team member budget {max_budget_in_team} with error: {e}, skipping.."
+            )
+            continue
 
 
 async def _update_litellm_setting(
@@ -471,21 +493,32 @@ async def update_sso_settings(sso_config: SSOConfig):
         config["general_settings"] = {}
 
     # Update environment variables in config and in memory
-    sso_data = sso_config.model_dump(exclude_none=True)
+    sso_data = sso_config.model_dump()
     for field_name, value in sso_data.items():
-
-        if field_name == "user_email" and value is not None:
-            # Store user_email in general_settings instead of environment variables
-            config["general_settings"]["proxy_admin_email"] = value
-        elif field_name == "ui_access_mode" and value is not None:
-
-            config["general_settings"]["ui_access_mode"] = value
-        elif field_name in env_var_mapping and value is not None:
+        if field_name == "user_email":
+            if value:
+                # Store user_email in general_settings instead of environment variables
+                config["general_settings"]["proxy_admin_email"] = value
+            else:
+                # Clear user_email if null/empty
+                config["general_settings"].pop("proxy_admin_email", None)
+        elif field_name == "ui_access_mode":
+            if value:
+                config["general_settings"]["ui_access_mode"] = value
+            else:
+                # Clear ui_access_mode if null/empty
+                config["general_settings"].pop("ui_access_mode", None)
+        elif field_name in env_var_mapping and value:
             env_var_name = env_var_mapping[field_name]
             # Update in config
             config["environment_variables"][env_var_name] = value
             # Update in runtime environment
             os.environ[env_var_name] = value
+        elif field_name in env_var_mapping:
+            # Clear environment variable if value is null/empty
+            env_var_name = env_var_mapping[field_name]
+            config["environment_variables"].pop(env_var_name, None)
+            os.environ.pop(env_var_name, None)
 
     stored_config = config
     if len(config["environment_variables"]) > 0:
@@ -501,3 +534,155 @@ async def update_sso_settings(sso_config: SSOConfig):
         "status": "success",
         "settings": sso_data,
     }
+
+
+@router.get(
+    "/get/ui_theme_settings",
+    tags=["UI Theme Settings"],
+    dependencies=[Depends(user_api_key_auth)],
+    response_model=UIThemeSettingsResponse,
+)
+async def get_ui_theme_settings():
+    """
+    Get UI theme configuration from the litellm_settings.
+    Returns current logo settings for UI customization.
+    """
+    from litellm.proxy.proxy_server import proxy_config
+
+    # Load existing config
+    config = await proxy_config.get_config()
+
+    return await _get_settings_with_schema(
+        settings_key="ui_theme_config",
+        settings_class=UIThemeConfig,
+        config=config,
+    )
+
+
+@router.patch(
+    "/update/ui_theme_settings",
+    tags=["UI Theme Settings"],
+    dependencies=[Depends(user_api_key_auth)],
+)
+async def update_ui_theme_settings(theme_config: UIThemeConfig):
+    """
+    Update UI theme configuration.
+    Updates logo settings for the admin UI.
+    """
+    from litellm.proxy.proxy_server import proxy_config, store_model_in_db
+    import os
+
+    if store_model_in_db is not True:
+        raise HTTPException(
+            status_code=500,
+            detail={
+                "error": "Set `'STORE_MODEL_IN_DB='True'` in your env to enable this feature."
+            },
+        )
+
+    # Load existing config
+    config = await proxy_config.get_config()
+    
+    # Update config with UI theme settings
+    if "general_settings" not in config:
+        config["general_settings"] = {}
+    
+    if "environment_variables" not in config:
+        config["environment_variables"] = {}
+
+    # Convert theme config to dict
+    theme_data = theme_config.model_dump(exclude_none=True)
+    
+    # Store UI theme config in litellm_settings (where it's retrieved from)
+    if "litellm_settings" not in config:
+        config["litellm_settings"] = {}
+    config["litellm_settings"]["ui_theme_config"] = theme_data
+    
+    # Update UI_LOGO_PATH environment variable if logo_url is provided
+    # If logo_url is empty string, None, or null, remove the environment variable to use default
+    logo_url = theme_data.get("logo_url")
+    verbose_proxy_logger.debug(f"Updating logo_url: {logo_url}")
+    
+    if logo_url and isinstance(logo_url, str) and logo_url.strip():  # Check if logo_url exists and is not empty/whitespace
+        config["environment_variables"]["UI_LOGO_PATH"] = logo_url
+        os.environ["UI_LOGO_PATH"] = logo_url
+        verbose_proxy_logger.debug(f"Set UI_LOGO_PATH to: {logo_url}")
+    else:
+        # Remove the environment variable to restore default logo
+        if "UI_LOGO_PATH" in config.get("environment_variables", {}):
+            del config["environment_variables"]["UI_LOGO_PATH"]
+            verbose_proxy_logger.debug("Removed UI_LOGO_PATH from config")
+        if "UI_LOGO_PATH" in os.environ:
+            del os.environ["UI_LOGO_PATH"]
+            verbose_proxy_logger.debug("Removed UI_LOGO_PATH from environment")
+
+    # Handle environment variable encryption if needed
+    stored_config = config.copy()
+    if "environment_variables" in stored_config and len(stored_config["environment_variables"]) > 0:
+        # Only encrypt if there are environment variables to encrypt
+        stored_config["environment_variables"] = proxy_config._encrypt_env_variables(
+            environment_variables=stored_config["environment_variables"]
+        )
+    
+    # Save the updated config
+    await proxy_config.save_config(new_config=stored_config)
+
+    return {
+        "message": "Logo settings updated successfully.",
+        "status": "success",
+        "theme_config": theme_data,
+    }
+
+
+@router.post(
+    "/upload/logo",
+    tags=["UI Theme Settings"],
+    dependencies=[Depends(user_api_key_auth)],
+)
+async def upload_logo(file: UploadFile = File(...)):
+    """
+    Upload a custom logo for the admin UI.
+    Accepts image files (PNG, JPG, JPEG, SVG) and stores them for use in the UI.
+    """
+    import os
+    from pathlib import Path
+
+    # Validate file type
+    allowed_extensions = {".png", ".jpg", ".jpeg", ".svg"}
+    file_extension = Path(file.filename or "").suffix.lower()
+    
+    if file_extension not in allowed_extensions:
+        raise HTTPException(
+            status_code=400,
+            detail=f"Invalid file type. Allowed types: {', '.join(allowed_extensions)}"
+        )
+    
+    # Validate file size (max 5MB)
+    file_content = await file.read()
+    if len(file_content) > 5 * 1024 * 1024:  # 5MB
+        raise HTTPException(
+            status_code=400,
+            detail="File size too large. Maximum size is 5MB."
+        )
+    
+    # Create uploads directory if it doesn't exist
+    current_dir = os.path.dirname(os.path.abspath(__file__))
+    upload_dir = os.path.join(current_dir, "..", "uploads")
+    os.makedirs(upload_dir, exist_ok=True)
+    
+    # Generate unique filename
+    from litellm._uuid import uuid
+    unique_filename = f"logo_{uuid.uuid4().hex}{file_extension}"
+    file_path = os.path.join(upload_dir, unique_filename)
+    
+    # Save the file
+    with open(file_path, "wb") as buffer:
+        buffer.write(file_content)
+    
+    return {
+        "message": "Logo uploaded successfully",
+        "status": "success",
+        "file_path": file_path,
+        "filename": unique_filename,
+        "file_size": len(file_content),
+    }
