@@ -1,17 +1,13 @@
-from typing import TYPE_CHECKING, Dict, List, Optional
+from typing import Any, Dict, List, Optional
 
 from pydantic import BaseModel, ConfigDict
 from typing_extensions import TypedDict
 
-from litellm.proxy._types import MCPAuthType, MCPSpecVersionType, MCPTransportType
+from litellm.proxy._types import MCPAuthType, MCPTransportType
 from litellm.types.mcp import MCPServerCostInfo
 
-
-class MCPInfo(TypedDict, total=False):
-    server_name: str
-    description: Optional[str]
-    logo_url: Optional[str]
-    mcp_server_cost_info: Optional[MCPServerCostInfo]
+# MCPInfo now allows arbitrary additional fields for custom metadata
+MCPInfo = Dict[str, Any]
 
 
 class MCPServer(BaseModel):
@@ -21,10 +17,15 @@ class MCPServer(BaseModel):
     server_name: Optional[str] = None
     url: Optional[str] = None
     transport: MCPTransportType
-    spec_version: MCPSpecVersionType
     auth_type: Optional[MCPAuthType] = None
     authentication_token: Optional[str] = None
     mcp_info: Optional[MCPInfo] = None
+    # OAuth-specific fields
+    client_id: Optional[str] = None
+    client_secret: Optional[str] = None
+    scopes: Optional[List[str]] = None
+    authorization_url: Optional[str] = None
+    token_url: Optional[str] = None
     # Stdio-specific fields
     command: Optional[str] = None
     args: Optional[List[str]] = None
