@@ -139,15 +139,19 @@ class _PROXY_LiteLLMManagedFiles(CustomLogger, BaseFileEndpoints):
             litellm_parent_otel_span=litellm_parent_otel_span,
         )
 
-        await self.prisma_client.db.litellm_managedobjecttable.create(
+        await self.prisma_client.db.litellm_managedobjecttable.upsert(
+            where={"unified_object_id": unified_object_id},
             data={
-                "unified_object_id": unified_object_id,
-                "file_object": file_object.model_dump_json(),
-                "model_object_id": model_object_id,
-                "file_purpose": file_purpose,
-                "created_by": user_api_key_dict.user_id,
-                "updated_by": user_api_key_dict.user_id,
-                "status": file_object.status,
+                "create": {
+                    "unified_object_id": unified_object_id,
+                    "file_object": file_object.model_dump_json(),
+                    "model_object_id": model_object_id,
+                    "file_purpose": file_purpose,
+                    "created_by": user_api_key_dict.user_id,
+                    "updated_by": user_api_key_dict.user_id,
+                    "status": file_object.status,
+                },
+                "update": {},  # don't do anything if it already exists
             }
         )
 
@@ -286,6 +290,7 @@ class _PROXY_LiteLLMManagedFiles(CustomLogger, BaseFileEndpoints):
             "aretrieve_fine_tuning_job",
             "alist_fine_tuning_jobs",
             "acancel_fine_tuning_job",
+            "mcp_call",
         ],
     ) -> Union[Exception, str, Dict, None]:
         """
